
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Music = {}
Music.__index = Music

-- =======================================================================

function Music.new()

	local new = {}
	setmetatable(new, Music)
	
	new.tracks = Collection.new()
	new:LoadTracks()

	return new

end

-- ... ===================================================================
-- =======================================================================

function Music:LoadTracks()
	
	self:LoadTrack('track01.ogg')
	self:LoadTrack('track02.ogg')
	self:LoadTrack('track03.ogg')
	self:LoadTrack('track04.ogg')

end

-- =======================================================================

function Music:LoadTrack (sourceFileName)
	
	local track = Track.new(sourceFileName)
	self.tracks:Add(track)

end

-- CONTROL ===============================================================
-- =======================================================================

function Music:Start()
	
	if self.started then
		return
	end

	if self.track then

		self.track:Stop()
		self.track = nil
		
	end

	self:StartNextTrack()
	self.started = true

end

-- =======================================================================

function Music:Stop()

	if not self.started then
		return
	end

	self.track:FadeOut(4)
	self.started = nil
	self.pause = nil

end

-- ... ===================================================================
-- =======================================================================

function Music:StartNextTrack()

	while (not self.track) or self.track == self.lastTrack do

		self.track = self.tracks:Random()

	end

	self.lastTrack = self.track
	self.track:Play()

end

-- ... ===================================================================
-- =======================================================================

function Music:ReceiveTimePulse (pulse)

	local pause = self.pause
	if pause then

		pause:ReceiveTimePulse(pulse)
		if pause:IsComplete() then

			self:StartNextTrack()
			self.pause = nil

		end

	else

		if self.started and self.track and self.track:IsStopped() then

			self.pause = Countdown.new(random:Value(4, 8))
			self.track = nil

		end

	end

	if self.track then

		self.track:ReceiveTimePulse(pulse)

	end

end
