
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Track = {}
Track.__index = Track

-- =======================================================================

function Track.new (sourceFileName)

	local new = {}
	setmetatable(new, Track)
	
	new:CreateSource(sourceFileName)

	return new

end

-- =======================================================================

function Track:CreateSource (sourceFileName)

	self.source = love.audio.newSource('assets/music/' .. sourceFileName, 'stream')

end

-- PLAY CONTROL ==========================================================
-- =======================================================================

function Track:Play()

	self.source:play()

end

-- =======================================================================

function Track:Stop()

	self.source:stop()

end

-- ======================================================================

function Track:IsStopped()
	
	return self.source:isStopped()

end

-- VOLUME ================================================================
-- ======================================================================

function Track:SetVolume (volume)
	
	self.source:setVolume(volume)

end

-- =======================================================================

function Track:GetVolume()
	
	return self.source:getVolume()

end

-- =======================================================================

function Track:FadeIn (duration)

	self.fadeIn = Countdown.new(duration)
	self.fadeStartVolume = self:GetVolume()

	self.fadeOut = nil

end

-- =======================================================================

function Track:FadeOut (duration)

	self.fadeOut = Countdown.new(duration)
	self.fadeStartVolume = self:GetVolume()

	self.fadeIn = nil

end

-- ... ===================================================================
-- =======================================================================

function Track:ReceiveTimePulse (pulse)

	local fadeIn = self.fadeIn
	local fadeOut = self.fadeOut
	
	if fadeIn then

		fadeIn:ReceiveTimePulse(pulse)
		self:SetVolume((1 - fadeIn:GetRelativeCountdown()) * self.fadeStartVolume)

		if fadeIn:IsComplete() then

			self.fadeIn = nil

		end

	end

	if fadeOut then
		
		fadeOut:ReceiveTimePulse(pulse)
		self:SetVolume(fadeOut:GetRelativeCountdown() * self.fadeStartVolume)

		if fadeOut:IsComplete() then

			self.fadeOut = nil
			self:Stop()

		end

	end

end
