
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Boot = {}
Boot.__index = Boot

-- =======================================================================

function Boot.new()

	local new = {}
	setmetatable(new, Boot)
	
	return new

end

-- =======================================================================

function Boot:Run()

	time = Time.new()
	
	luck = Luck.new()
	random = Random.new()

	mouse = Mouse.new()
	keyboard = Keyboard.new()

	music = Music.new()

	eventTexts = EventTexts.new()
	explanationTexts = ExplanationTexts.new()

	achievements = Achievements.new()
	backstories = Backstories.new()
	explanations = Explanations.new()
	tutorials = Tutorials.new()

	explanationTexts = nil

	sounds = Sounds.new()
	sprites = Sprites.new()
	
	local cursor = love.mouse.newCursor('assets/cursors/cursor.png', 0, 0)
	love.mouse.setCursor(cursor)
	
	self:InitData()
	self:InitDevConsole()
	self:InitScreens()
	
	self:Temp_InitSkin()
	self:InitFonts()

	local persistenceDataPath = consts.persistenceFilePath
	if checkFileExists(persistenceDataPath) then

		local pl = PersistenceLoader.new()
		pl:Load(persistenceDataPath)

	end

end
-- =======================================================================

function Boot:InitData()

	chipEntities = StaticEntities.new(Chip, 'data/chips.xml')
	consoleEntities = StaticEntities.new(Console, 'data/consoles.xml')
	dataLabelEntities = StaticEntities.new(DataLabel, 'data/dataLabels.xml')
	organisations = StaticEntities.new(Organisation, 'data/organisations.xml')
	roles = StaticEntities.new(Role, 'data/roles.xml')

	roles = StaticEntities.new(Role, 'data/roles.xml')

	names = Names.new('data/names.xml')

	relationshipStatuses = RelationshipStatuses.new('data/relationships.xml')

end

-- =======================================================================

function Boot:InitDevConsole()

	devConsole = DevConsole.new()

	for name, value in Map.new(devConsoleVars):Each() do
		devConsole:LearnVar(name, value)
	end

	for name, action in Map.new(devConsoleCommands):Each() do
		devConsole:LearnCommand(name, action)
	end

	if checkFileExists(consts.consoleBootFilePath) then
		devConsole:ExecuteFile(consts.consoleBootFilePath)
	end

end

-- =======================================================================

function Boot:InitFonts()

	fonts = Fonts.new()
	fonts:CreateFonts()

end

-- =======================================================================

function Boot:InitScreens()

	screen = Screen.new()

	aspirationsScreen = AspirationsScreen.new()
	backstoriesScreen = BackstoriesScreen.new()
	chipScreen = ChipScreen.new()
	characterScreen = CharacterScreen.new()
	connectionScreen = ConnectionScreen.new()
	consoleScreen = ConsoleScreen.new()
	coordinateScreen = CoordinateScreen.new()
	creditsScreen = CreditsScreen.new()
	dataScreen = DataScreen.new()
	deckScreen = DeckScreen.new()
	menuScreen = MenuScreen.new()
	moduleScreen = ModuleScreen.new()
	networkScreen = NetworkScreen.new()
	operationScreen = OperationScreen.new()
	tutorialsScreen = TutorialsScreen.new()

end

-- =======================================================================

function Boot:Temp_InitSkin()

	skin = Skin.new('skin1', 'assets/skins/skin1')
	skin:Load()

end
