
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

devConsoleVars = 
{
	['draw_FPS'] = 0,
	['music'] = 1,
	['press_tab_to_exit'] = 0
}

-- =======================================================================

devConsoleCommands = {}

-- =======================================================================

devConsoleCommands['access_node'] = function (self, ID)

	if not (self:CheckNumberParam(ID, 'ID') and self:CheckNetworkScreen()) then
		return
	end

	local node = self:GetNodeWithID(ID)
	if not node then
		return
	end

	node:GainAccess()

end

-- =======================================================================

devConsoleCommands['access_all_nodes'] = function (self)

	if not self:CheckNetworkScreen() then
		return
	end

	local network = networkScreen:GetNetwork()
	for node in network:GetNodes():Each() do

		node:GainAccess()

	end

end

-- =======================================================================

devConsoleCommands['add_credits'] = function (self, amount)

	if not self:CheckNumberParam(amount, 'amount') then
		return
	end

	credits:Add(amount)

end

-- =======================================================================

devConsoleCommands['add_max_tokens'] = function (self)

	if not self:CheckNetworkScreen() then
		return
	end

	local tokens = networkScreen:GetRun():GetTokens()
	tokens:Add(tokens:GetMaxCount() - tokens:GetCount())
	
end

-- =======================================================================

devConsoleCommands['add_module'] = function (self, ID)

	assets:AddModule(ID)

end

-- =======================================================================

devConsoleCommands['add_tokens'] = function (self, count)

	if not (self:CheckNumberParam(count, 'count') and self:CheckNetworkScreen()) then
		return
	end

	networkScreen:GetRun():GetTokens():Add(count)

end

-- =======================================================================

devConsoleCommands['alert_node'] = function (self, ID)

	if not (self:CheckNumberParam(ID, 'ID') and self:CheckNetworkScreen()) then
		return
	end

	local node = self:GetNodeWithID(ID)
	if not node then
		return
	end

	node:Alert()

end

-- =======================================================================

devConsoleCommands['breach_router'] = function (self, ID)

	if not (self:CheckNumberParam(ID, 'ID') and self:CheckNetworkScreen()) then
		return
	end

	local node = self:GetNodeWithID(ID)
	if not node then
		return
	end

	if node:GetClass() ~= NodeClass.Router then

		self:PrintError(strFormat("The node with ID %d is not a Router."))
		return

	end

	node:Breach(BreachContext.new({ impact = true, undetectable = true }))

end

-- =======================================================================

devConsoleCommands['clear_persistence'] = function (self)

	if checkFileExists(consts.persistenceFilePath) then

		deleteFile(consts.persistenceFilePath)

	end

end

-- =======================================================================

devConsoleCommands['close_lovebird'] = function (self)

	lovebird = nil

end

-- =======================================================================

devConsoleCommands['connect_to_network'] = function (self, index, rank)

	if not (self:CheckNumberParam(index, 'index') and self:CheckNumberParam(rank, 'rank')) then
		return
	end

	local networkBuilder = NetworkBuilder.new(Coordinate.new({ index = index, rank = rank }))
	local network = networkBuilder:Build()
	screen:Set(networkScreen, { network = network })

end

-- =======================================================================

devConsoleCommands['open_lovebird'] = function (self)

	lovebird = require('scripts.ext.lovebird.lovebird')

end

-- =======================================================================

devConsoleCommands['set_deck_console'] = function (self, console)

	if not self:CheckStrParam(console, 'console') then
		return
	end

	deck:SetConsole(console)

end

-- =======================================================================

devConsoleCommands['set_deck_module'] = function (self, slot, module)

	if not (self:CheckNumberParam(slot, 'slot') and self:CheckStrParam(module, 'module')) then
		return
	end

	deck:GetModules():SetItem(slot, module)

end

-- =======================================================================

devConsoleCommands['start_new_game'] = function (self)

	newGameStarter = NewGameStarter.new(Collection.new())
	newGameStarter:StartNewGame()

	screen:Set(characterScreen)

end

-- =======================================================================

devConsoleCommands['start_tutorial'] = function (self, ID)

	local tutorial = tutorials:GetTutorial(ID)
	tutorialsScreen:StartTutorial(tutorial)

end

-- =======================================================================

devConsoleCommands['start_trace'] = function (self)

	if not self:CheckNetworkScreen() then
		return
	end

	local curX, curY = mouse:GetCursorPos()
	local node = networkScreen:GetNetworkRender():GetNodeOnScreenCoords(curX, curY)

	if not node then

		self:PrintError("There has to be a node under the mouse cursor to execute this command.")
		return

	end

	if node:GetClass() ~= NodeClass.Router then

		self:PrintError("The node under the mouse cursor has to be a Router.")
		return

	end

	networkScreen:GetNetwork():StartTrace(node)

end

-- =======================================================================

devConsoleCommands['stop_trace'] = function (self)

	if not self:CheckNetworkScreen() then
		return
	end

	networkScreen:GetNetwork():StopTrace()

end
