
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NetworkControl = {}
NetworkControl.__index = NetworkControl

-- =======================================================================

function NetworkControl.new (network)

	local new = {}
	setmetatable(new, NetworkControl)
	
	new.network = network
	new.cameraControl = CameraControl.new()
	
	new:Hook()

	return new

end

-- =======================================================================

function NetworkControl:Release()

	self:Unhook()

end

-- =======================================================================
-- =======================================================================

function NetworkControl:Hook()
	
	networkScreen:GetMouseEvents().onMouseButtonPress:Subscribe(self)
	networkScreen:GetMouseEvents().onMouseButtonRelease:Subscribe(self)

end

-- =======================================================================

function NetworkControl:Unhook()
	
	networkScreen:GetMouseEvents().onMouseButtonPress:Unsubscribe(self)
	networkScreen:GetMouseEvents().onMouseButtonRelease:Unsubscribe(self)
	
end

-- =======================================================================
-- =======================================================================

function NetworkControl:OnMouseButtonPress (button, curX, curY)

	-- Camera
	if button == MouseButton.Right then

		self.cameraControl:StartMousePull()
		self:ClearActiveModule()

	end

end

-- =======================================================================

function NetworkControl:OnMouseButtonRelease (button, curX, curY)

	local node = networkScreen.networkRender:GetNodeOnScreenCoords(curX, curY)
	if node then

		-- Active module:
		if button == MouseButton.Left and self.activeModule and self.activeModule:GetUse() == ModuleUse.Node then
			if self.activeModule:CanExecuteOnNode(node) then

				self.activeModule:ExecuteOnNode(node)
				self:ClearActiveModule()
				return

			end
		end

		local nodeRender = networkScreen.networkRender:GetNodeRender(node) 
		nodeRender:OnMouseButtonRelease(button, curX, curY)

	end

	local subroutine = networkScreen.networkRender:GetSubroutineOnScreenCoords(curX, curY)
	if subroutine then

		-- Active module:
		if button == MouseButton.Left and self.activeModule and self.activeModule:GetUse() == ModuleUse.Subroutine then
			if self.activeModule:CanExecuteOnSubroutine(subroutine) then

				self.activeModule:ExecuteOnSubroutine(subroutine)
				self:ClearActiveModule()
				return

			end
		end

	end

	if button == MouseButton.Right then
		self.cameraControl:EndMousePull()
	end

end

-- ... ===================================================================
-- =======================================================================

function NetworkControl:SetActiveModule (module)

	self.activeModule = module

end

-- =======================================================================

function NetworkControl:ClearActiveModule()
	
	self.activeModule = nil

end

-- =======================================================================

function NetworkControl:GetActiveModule()
	
	return self.activeModule

end

-- ... ===================================================================
-- =======================================================================

function NetworkControl:GetCameraControl()

	return self.cameraControl

end

