
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

local builder = CharacterBuilder:NewClass
{
	ID = 'street:hardware-vendor',
	role = 'hardware-vendor'
}

-- =======================================================================

function builder:Construct()

	self:CreateChipStockEvent()
	self:CreateChipPruneEvent()

	self:CreateConsoleStockEvent()
	self:CreateConsolePruneEvent()

	self:CreatePurchaseEvent()
	self:CreateDeteriorateRelationshipEvent()
	self:CreateLeaveEvent()
	
	self:CreateIntroductionEvent()

end

-- CHIPS ==================================================================
-- =======================================================================

function builder:CreateChipStockEvent()

	local rank = self.details['chip_rank']
	local character = self.character

	-- All modules
	local items = Collection.new()
	
	items:Add(Values.new({ item = '{36c78291-ca0c-4dde-b71f-e19fdc8aff67}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{25ccb714-197a-49be-a17f-aed19669674c}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{4e08b293-2033-430f-9d1f-f4f51b2ed402}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{24ca01f8-3d57-474d-8113-5222a046c20b}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{6749d3b3-f196-48ec-9e08-7038f4d009fd}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{980d36cd-bde1-4a51-ab46-a0522065e8d9}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{82387432-5d8c-4128-9683-43ab0fa944c7}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{3a8bd7e1-b1b8-48d7-b26a-8be7d8a3862d}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d17e7820-b9fc-4cbe-a9d8-882532502585}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d07ca7be-b134-4ee6-a7a4-c52de76663f5}', rank = 1, chance = 10, price_base = 25, price_random = 5 }))
	items:Add(Values.new({ item = '{c139683f-8d94-42aa-9bf6-3345085d8d72}', rank = 1, chance = 10, price_base = 20, price_random = 5 }))
	items:Add(Values.new({ item = '{4727f71e-ea14-421e-94d6-ea8d03e4a397}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{e2489aec-b15a-48a4-aed6-369823873ddc}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{1ed3bbb4-5f87-4a97-b5ef-af2f93e10d3a}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{4469e7c9-94bd-418f-8418-be2c89196edd}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{693b03c0-317d-43e6-974e-c4092b02156f}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{dd49221a-d42e-45cc-b16d-2bce333f93ed}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))

	-- Create the event
	local pool = CharacterBuilder.Utils.BuildItemPool(items, rank, random:IntValue(18, 24))
	local event = character:NewEvent('vendor:stock-items', { pool = pool, class = ItemClass.Chip, allow_duplicates = true, price_unit = 250 })
	event:SetChance(random:Value(0.35, 0.45))

	-- Init stock
	for _ = 1, random:IntValue(6, 12) do
		event:Invoke()
	end

end

-- =======================================================================

function builder:CreateChipPruneEvent()
	
	local character = self.character

	local event = character:NewEvent('vendor:prune-items', { class = ItemClass.Chip })
	event:SetChance(random:Value(0.15, 0.25))

end

-- CONSOLES ==============================================================
-- =======================================================================

function builder:CreateConsoleStockEvent()

	local rank = self.details['console_rank']
	local character = self.character

	-- All modules
	local items = Collection.new()
	
	items:Add(Values.new({ item = 'console-2', rank = 1, chance = 10, price_base = 45, price_random = 10 }))
	items:Add(Values.new({ item = 'console-3', rank = 1, chance = 10, price_base = 65, price_random = 25 }))

	-- Create the event
	local pool = CharacterBuilder.Utils.BuildItemPool(items, rank, random:IntValue(2, 4))
	local event = character:NewEvent('vendor:stock-items', { pool = pool, class = ItemClass.Console, allow_duplicates = false, price_unit = 250 })
	event:SetChance(random:Value(0.1, 0.2))

	-- Init stock
	for _ = 1, random:IntValue(2, 3) do
		event:Invoke()
	end

end

-- =======================================================================

function builder:CreateConsolePruneEvent()
	
	local character = self.character

	local event = character:NewEvent('vendor:prune-items', { class = ItemClass.Console })
	event:SetChance(random:Value(0.05, 0.075))

end

-- ... ===================================================================
-- =======================================================================

function builder:CreatePurchaseEvent()
	
	local character = self.character
	character:NewEvent('vendor:increase-relationship-on-purchase', { mod = random:Value(0.0015, 0.0025) })

end

-- =======================================================================

function builder:CreateDeteriorateRelationshipEvent()
	
	local character = self.character
	character:NewEvent('common:relationship:deteriorate-with-time', { mod = random:Value(0.25, 0.75) })

end


-- =======================================================================

function builder:CreateLeaveEvent()

	local character = self.character
	character:NewEvent('common:relationship:leave-when-low', {})

end

-- =======================================================================

function builder:CreateIntroductionEvent()

	local character = self.character
	character:NewEvent('street:introduction:switch', {})

end

