
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

local builder = CharacterBuilder:NewClass
{
	ID = 'street:hustler',
	role = 'hustler'
}

-- =======================================================================

function builder:Construct()

	local character = self.character
	character:MakeAcceptData()

	self:CreateChipStockEvent()
	self:CreateChipPruneEvent()

	self:CreateConsoleStockEvent()
	self:CreateConsolePruneEvent()

	self:CreateModuleStockEvent()
	self:CreateModulePruneEvent()

	self:CreatePurchaseEvent()
	self:CreateDeteriorateRelationshipEvent()
	self:CreateLeaveEvent()
	
	self:CreateIntroductionEvent()

end

-- CHIPS ==================================================================
-- =======================================================================

function builder:CreateChipStockEvent()

	local rank = self.details['chip_rank']
	local character = self.character

	-- All modules
	local items = Collection.new()
	
	items:Add(Values.new({ item = '{36c78291-ca0c-4dde-b71f-e19fdc8aff67}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{25ccb714-197a-49be-a17f-aed19669674c}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{4e08b293-2033-430f-9d1f-f4f51b2ed402}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{24ca01f8-3d57-474d-8113-5222a046c20b}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{6749d3b3-f196-48ec-9e08-7038f4d009fd}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{980d36cd-bde1-4a51-ab46-a0522065e8d9}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{82387432-5d8c-4128-9683-43ab0fa944c7}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{3a8bd7e1-b1b8-48d7-b26a-8be7d8a3862d}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d17e7820-b9fc-4cbe-a9d8-882532502585}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d07ca7be-b134-4ee6-a7a4-c52de76663f5}', rank = 1, chance = 10, price_base = 25, price_random = 5 }))
	items:Add(Values.new({ item = '{c139683f-8d94-42aa-9bf6-3345085d8d72}', rank = 1, chance = 10, price_base = 20, price_random = 5 }))
	items:Add(Values.new({ item = '{4727f71e-ea14-421e-94d6-ea8d03e4a397}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{e2489aec-b15a-48a4-aed6-369823873ddc}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{1ed3bbb4-5f87-4a97-b5ef-af2f93e10d3a}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{4469e7c9-94bd-418f-8418-be2c89196edd}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{693b03c0-317d-43e6-974e-c4092b02156f}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{dd49221a-d42e-45cc-b16d-2bce333f93ed}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))

	-- Create the event
	local pool = CharacterBuilder.Utils.BuildItemPool(items, rank, random:IntValue(18, 24))
	local event = character:NewEvent('vendor:stock-items', { pool = pool, class = ItemClass.Chip, allow_duplicates = true, price_unit = 250 })
	event:SetChance(random:Value(0.2, 0.25))

	-- Init stock
	for _ = 1, random:IntValue(4, 8) do
		event:Invoke()
	end

end

-- =======================================================================

function builder:CreateChipPruneEvent()
	
	local character = self.character

	local event = character:NewEvent('vendor:prune-items', { class = ItemClass.Chip })
	event:SetChance(random:Value(0.15, 0.25))

end

-- CONSOLES ==============================================================
-- =======================================================================

function builder:CreateConsoleStockEvent()

	local rank = self.details['console_rank']
	local character = self.character

	-- All modules
	local items = Collection.new()
	
	items:Add(Values.new({ item = 'console-2', rank = 1, chance = 10, price_base = 45, price_random = 10 }))
	items:Add(Values.new({ item = 'console-3', rank = 1, chance = 10, price_base = 65, price_random = 25 }))

	-- Create the event
	local pool = CharacterBuilder.Utils.BuildItemPool(items, rank, random:IntValue(2, 4))
	local event = character:NewEvent('vendor:stock-items', { pool = pool, class = ItemClass.Console, allow_duplicates = false, price_unit = 250 })
	event:SetChance(random:Value(0.05, 0.1))

	-- Init stock
	for _ = 1, random:IntValue(2, 3) do
		event:Invoke()
	end

end

-- =======================================================================

function builder:CreateConsolePruneEvent()
	
	local character = self.character

	local event = character:NewEvent('vendor:prune-items', { class = ItemClass.Console })
	event:SetChance(random:Value(0.025, 0.1))

end

-- MODULES ===============================================================
-- =======================================================================

function builder:CreateModuleStockEvent()

	local rank = self.details['module_rank']
	local character = self.character

	-- All modules
	local items = Collection.new()
	items:Add(Values.new({ item = '{ebe3a219-5a69-4f56-81f9-6341c6f2b846}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{2ac3ea8e-493a-4029-9dfa-3d91769392d4}', rank = 1, chance = 50, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{597f7d8e-948d-45b6-9844-2a433ec3e8eb}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{73750128-630e-4b3e-a865-9b2147ef5214}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{751970ca-e871-4ff2-af33-9b91d0b571de}', rank = 1, chance = 25, price_base = 25, price_random = 10 }))
	items:Add(Values.new({ item = '{ca6add11-d2ed-11e3-9c1a-20ab7e004562}', rank = 1, chance = 20, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{ceee7b53-cb2c-490b-b78c-24d26d0bab08}', rank = 1, chance = 20, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{461c104a-b0a3-4701-9c5a-19f4a9c21ccb}', rank = 1, chance = 35, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{dcf63bbb-6e81-4f6f-97c1-fcdbccbdda0b}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{6064bbf6-c071-4718-b882-77f19b549d1e}', rank = 1, chance = 20, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{dceff74a-747b-4bdf-8eff-1992176a2dac}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d1b08a21-51cf-4b8c-bbad-2396aab9b0d5}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{da2db277-fcf2-4dac-bcdd-379d4c61fe22}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{9c54e5c4-26d3-418c-ae3c-8b927ec14b70}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{6fe96f9c-a78c-4529-89d3-ef5775afd2d9}', rank = 1, chance = 00, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{cae68356-ed33-4ad2-973e-cefb49ad9f2f}', rank = 1, chance = 35, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{d30f2e71-950b-4366-b26e-e3f22f51fd53}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{c4f2db4b-0252-43fc-ac83-617736586173}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{bfed5cbd-51cb-4128-a969-47c06de5b6b1}', rank = 1, chance = 25, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{932d9ecf-6668-482c-854d-8addae02a8dc}', rank = 1, chance = 25, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{aeec997f-32df-4c1e-8140-6715a7745d27}', rank = 1, chance = 35, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{96114876-1a81-42bb-af2e-f3271e5bf637}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{a515d826-4fc0-4d25-83c9-2f699dd6869b}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{535a8ece-f25d-4aff-b022-379f3723aaae}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{6e8ad689-8ae7-48cc-b972-0b4cf5bf9bf2}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{10b6dbd9-48d5-46a2-9f98-e55c490c765b}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{4f0bf92b-c3e2-4f1d-9d4b-6f37eacdf86e}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{13aee470-8832-46e0-9e06-985ce06a540d}', rank = 1, chance = 65, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{0bdf7e7f-73b9-4c0a-b4d6-0f060d0df94f}', rank = 1, chance = 35, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{89575252-49e6-48c4-9a2e-89b77d68b614}', rank = 1, chance = 25, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{571a384b-13b6-4a5b-908e-32dcfed1dcf0}', rank = 1, chance = 10, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{3614c794-427d-4e9c-b178-4b086f5a7174}', rank = 1, chance = 15, price_base = 10, price_random = 5 }))
	items:Add(Values.new({ item = '{673fe5ca-58a7-4e88-b133-8851835add08}', rank = 1, chance = 45, price_base = 10, price_random = 5 }))

	-- Create the event
	local pool = CharacterBuilder.Utils.BuildItemPool(items, rank, random:IntValue(15, 25))
	local event = character:NewEvent('vendor:stock-items', { pool = pool, class = ItemClass.Module, allow_duplicates = false, price_unit = 250 })
	event:SetChance(random:Value(0.25, 0.35))

	-- Init stock
	for _ = 1, random:IntValue(2, 6) do
		event:Invoke()
	end

end

-- =======================================================================

function builder:CreateModulePruneEvent()
	
	local character = self.character

	local event = character:NewEvent('vendor:prune-items', { class = ItemClass.Module })
	event:SetChance(random:Value(0.1, 0.2))

end

-- ... ===================================================================
-- =======================================================================

function builder:CreatePurchaseEvent()
	
	local character = self.character
	character:NewEvent('vendor:increase-relationship-on-purchase', { mod = random:Value(0.0015, 0.0025) })

end

-- =======================================================================

function builder:CreateDeteriorateRelationshipEvent()
	
	local character = self.character
	character:NewEvent('common:relationship:deteriorate-with-time', { mod = random:Value(0.25, 0.75) })

end


-- =======================================================================

function builder:CreateLeaveEvent()

	local character = self.character
	character:NewEvent('common:relationship:leave-when-low', {})

end

-- =======================================================================

function builder:CreateIntroductionEvent()

	local character = self.character
	character:NewEvent('street:introduction:switch', {})

end

