
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

DevConsoleCommand = {}
DevConsoleCommand.__index = DevConsoleCommand

-- =======================================================================

function DevConsoleCommand.new (console, name, action)

	local new = {}
	setmetatable(new, DevConsoleCommand)

	new.console = console
	new.name = name
	new.action = action

	return new

end

-- =======================================================================

function DevConsoleCommand:Execute (...)

	self:action(unpack({...}))

end

-- =======================================================================

function DevConsoleCommand:Print (kind, text)

	self.console:PushLine(kind, text)

end

-- UTILITY: OUTPUT =======================================================
-- =======================================================================

function DevConsoleCommand:PrintError (text)
	
	self:Print(DevConsoleLineKind.CommandError, text)

end

-- UTILITY: PARAM CHECK ==================================================
-- =======================================================================

function DevConsoleCommand:CheckNumberParam (value, name)
	
	if not isNumber(value) then

		self:PrintError(strFormat("Invalid numeric parameter '%s'.", name))
		return

	end

	return true

end

-- =======================================================================

function DevConsoleCommand:CheckStrParam (value, name)
	
	if not isStr(value) then

		self:PrintError(strFormat("Invalid parameter '%s'.", name))
		return

	end

	return true

end

-- UTILITY: CONTEXT CHECK ================================================
-- =======================================================================

function DevConsoleCommand:CheckNetworkScreen()

	if screen:GetCurrent() ~= networkScreen then
		
		self:PrintError("This command cannot be used outside a network run.")
		return

	end

	return true
	
end

-- UTILITY: NETWORK ======================================================
-- =======================================================================

function  DevConsoleCommand:GetNodeWithID (ID)
	
	local network = networkScreen:GetNetwork()
	local node = network:GetNodeWithID(ID)

	if not node then

		self:PrintError(strFormat("The network doesn't contain a node with ID %d.", ID))
		return

	end

	return node

end
