
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz
	
require('scripts.requires')
		
-- =======================================================================

function love.load()

	boot = Boot.new()
	boot:Run()

	screen:Set(menuScreen)

	if checkFileExists(consts.consoleStartFilePath) then
		devConsole:ExecuteFile(consts.consoleStartFilePath)
	end

	-- ===
	-- ...
	-- ===

end

-- =======================================================================

function love.draw()

	screen:Draw()
	devConsole:Draw()
	drawFPS()

end

-- =======================================================================

function drawFPS() 

	if not devConsole:GetVar('draw_FPS'):IsEnabled() then
		return
	end

	drawFpsFont = drawFpsFont or love.graphics.newFont('assets/fonts/Exo2-Medium.otf', 12)
	love.graphics.setFont(drawFpsFont)

	love.graphics.setColor(192, 192, 192)
	love.graphics.printf('FPS: ' .. love.timer.getFPS(), love.window.getWidth() - 64, 4, 64 - 4, 'right')

end

-- =======================================================================

function love.update (dt)

	if not screen:GetCurrent():ShowsExplanation() then

		loveFrames.update(dt)

	end

	mouse:OnFrameStart()

	time:ReceivePulse(dt)
	random:ReceiveImpulse(math.ceil(os.time()*dt))

	if lovebird then
		lovebird.update()
	end

end

-- =======================================================================

function love.mousepressed (curX, curY, button)

	local s = screen:GetCurrent()
	if s:ShowsExplanation() then

		s:HideExplanation()
		return

	end

	loveFrames.mousepressed(curX, curY, button)

	if button == 'l' then
		mouse:OnMouseButtonPress(MouseButton.Left, curX, curY)
	end

	if button == 'r' then
		mouse:OnMouseButtonPress(MouseButton.Right, curX, curY)
	end

end

-- =======================================================================

function love.mousereleased (curX, curY, button)

	loveFrames.mousereleased(curX, curY, button)

	if button == 'l' then
		mouse:OnMouseButtonRelease(MouseButton.Left, curX, curY)
	end

	if button == 'r' then
		mouse:OnMouseButtonRelease(MouseButton.Right, curX, curY)
	end

end

-- =======================================================================

function love.keypressed (key, isRepeat)

	if devConsole:IsVisible() then

		if table.contains({'`', 'escape'}, key) then

			devConsole:Hide()
			return

		end

		devConsole:OnKeyPress(key)
		return

	end

	if key == '`' then

		devConsole:Show()
		return

	end

	loveFrames.keypressed(key)
	keyboard:OnKeyPress(key, isRepeat)

	if key == 'tab' and devConsole:GetVar('press_tab_to_exit'):IsEnabled() then

		local ps = PersistenceSaver.new()
		ps:Save(consts.persistenceFilePath)

		love.event.quit()

	end

	if screen:GetCurrent() == networkScreen then

		local curX, curY = love.mouse.getPosition()
		local node = networkScreen.networkRender:GetNodeOnScreenCoords(curX, curY)
		local subroutine = networkScreen.networkRender:GetSubroutineOnScreenCoords(curX, curY)

		local modulesRender = networkScreen.modulesRender
		for _, moduleRender in ipairs(modulesRender.moduleRenders) do

			if key == moduleRender:GetShortcut() then
				moduleRender:ExecuteShortcut()
			end

		end

	end

end

-- =======================================================================

function love.keyreleased (key)

	loveFrames.keyreleased(key)
	keyboard:OnKeyRelease(key)

end

-- =======================================================================

function love.textinput (text)

	if devConsole:IsVisible() and text ~= '`' then

		devConsole:OnTextInput(text)
		return

	end

	loveFrames.textinput(text)
	keyboard:OnTextInput(text)

end

