
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Achievements = {}
Achievements.__index = Achievements

-- =======================================================================

function Achievements.new()

	local new = {}
	setmetatable(new, Achievements)
	
	new.achievements = Map.new()
	new:Init()

	return new

end

-- INIT ==================================================================
-- =======================================================================

function Achievements:Init()
	
	self:InitAchievement('_001')
	self:InitAchievement('_002')
	self:InitAchievement('_003')
	self:InitAchievement('_004')
	self:InitAchievement('GAIA')

end

-- =======================================================================

function Achievements:InitAchievement (ID)
	
	assert(not self.achievements:ContainsKey(ID), strFormat("Achievement with ID '%s' would be overwritten.", ID))

	local achievement = Achievement:NewInstance(ID)
	self.achievements[ID] = achievement

end

-- REACTIONS =============================================================
-- =======================================================================

function Achievements:ReceiveImpulse (impulse, context)

	local isNotComplete = function (a) return not a:IsComplete() end
	for achievement in self.achievements:SelectValues(isNotComplete):EachValue() do

		local context = Values.new(context)
		achievement:React(impulse, context)

	end
	
end

-- ... ===================================================================
-- =======================================================================

function Achievements:GetAspirations()
	
	local isAspiration = function (a) return a:GetClass() == AchievementClass.Aspiration end
	return self.achievements:SelectValues(isAspiration):ListValues()

end

-- EXPOSE ================================================================
-- =======================================================================

function Achievements:GetAchievements()
	
	return self.achievements:ListValues()

end

-- =======================================================================

function Achievements:GetAchievement (ID)
	
	return assert(self.achievements[ID], strFormat("Achivement with ID '%s' doesn't exist.", ID))

end

