
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Character = {}
Character.__index = Character

-- =======================================================================

function Character.new (name)

	local new = {}
	setmetatable(new, Character)
	
	new.name = name

	new.events = Collection.new()
	new.values = Values.new()
	new.items = Map.new()
	new.operations = Collection.new()
	new.relationship = Relationship.new()

	return new

end

-- ITEMS =================================================================
-- =======================================================================

function Character:AddItem (item)
	
	local class = item:GetClass()
	if not self.items:ContainsKey(class) then
		self.items[class] = ItemCollection.new()
	end

	self.items[class]:AddItem(item)

end

-- =======================================================================

function Character:DealsItems (class)
	
	return self.items:ContainsKey(class)

end

-- =======================================================================

function Character:GetItems (class)

	return assert(self.items[class], strFormat("Character '%s' doesn't deal with item class '%s'.", self.name, class:ToStr()))

end

-- =======================================================================

function Character:OwnsItem (class, item)

	return self:DealsItems(class) and self.items[class]:ContainsItem(item)

end

-- DATA ==================================================================
-- =======================================================================

function Character:MakeAcceptData()

	self.purchasesData = true

end

-- =======================================================================

function Character:AcceptsData()
	
	return self.purchasesData

end

-- =======================================================================

function Character:AppraiseData (data)
	
	-- ===
	-- TEMPORARY ---
	-- ===

	local r = tonumber(tostring(data):sub(-4), 16)
	return 150 + 25 * (r % 25) + 25 * math.ceil(data:GetSize()/250)

end

-- EVENTS ================================================================
-- =======================================================================

function Character:NewEvent (ID, values)
	
	local new = Event:NewInstance(ID, values, self)
	self.events:Add(new)

	return new

end

-- =======================================================================

function Character:RemoveEvent (event)
	
	self.events:RemoveValue(event)

end

-- OPERATIONS ============================================================
-- =======================================================================

function Character:AddOperation (operation)
	
	self.operations:Add(operation)
	operation.character = self

end

-- =======================================================================

function Character:CompleteOperation (operation)
	
	self.operations:RemoveValue(operation)
	eventStarter:ReceiveImpulse(EventImpulse.OperationComplete, { operation = operation, character = self })

end

-- =======================================================================

function Character:AbandonOperation (operation)
	
	self.operations:RemoveValue(operation)
	eventStarter:ReceiveImpulse(EventImpulse.OperationFail, { operation = operation, character = self })

end

-- =======================================================================

function Character:GetOperations()
	
	return self.operations

end

-- LEAVE =================================================================
-- =======================================================================

function Character:Leave()
	
	characters:RemoveCharacter(self)

	-- Events that the character already has lined-up 
	-- in the event queue have to be discarded. 
	eventQueue:DiscardCharacterEvents(self)

	for event in self.events:Each() do
		event:Unsubscribe()
	end

end

-- ROLE ==================================================================
-- =======================================================================

function Character:SetRole (role)
	
	self.role = role

end

-- =======================================================================

function Character:GetRole()
	
	return self.role

end

-- AFFILIATION ===========================================================
-- =======================================================================

function Character:SetAffiliation (organisation)
	
	self.affiliation = organisation

end

-- =======================================================================

function Character:GetAffiliation()
	
	return self.affiliation

end

-- GAME TIME =============================================================
-- =======================================================================

function Character:ReceiveTick()

	for operation in self.operations:Each() do
		operation:ReceiveTick()
	end

end

-- EXPOSE ================================================================
-- =======================================================================

function Character:GetName()
	
	return self.name

end

-- =======================================================================

function Character:GetValues()
	
	return self.values

end

-- =======================================================================

function Character:GetRelationship()
	
	return self.relationship

end

