
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Chip = {}
Chip.__index = Chip

-- =======================================================================

function Chip.new (xmlRoot)

	local new = {}
	setmetatable(new, Chip)
	
	new.aspects = Collection.new()
	new.fuses = Collection.new()

	new:LoadFromXML(xmlRoot)

	return new

end

-- =======================================================================

function Chip:LoadFromXML (xmlRoot)
	
	self.ID = assert(xmlRoot:GetAttribute('ID'), "Invalid chip ID.")
	self.name = assert(xmlRoot:GetAttribute('name'), strFormat("Chip with ID '%s' declared without a name.", self.ID))

	local descriptionElement = assert(xmlRoot:GetElement('description'), strFormat("Chip with ID '%s' is declared without a description.", self.ID))
	self.description = descriptionElement:GetContent()

	for _, aspectElement in xmlRoot:EachElement('aspect') do

		local aspect = DeckAspect.new(aspectElement)
		self.aspects:Add(aspect)

	end

	for _, fuseElement in xmlRoot:EachElement('fuse') do

		local fuse = assert(fuseElement:GetAttribute('fuse'), strFormat("Fuse on the chip '%s' doesn't have its 'fuse' attribute declared.", self.ID))
		self.fuses:Add(fuse)

	end

end

-- EXPOSE ================================================================
-- =======================================================================

function Chip:GetID()

	return self.ID

end

-- =======================================================================

function Chip:GetName()

	return self.name

end

-- =======================================================================

function Chip:GetAspects()
	
	return self.aspects

end

-- =======================================================================

function Chip:GetFuses()
	
	return self.fuses

end

-- =======================================================================

function Chip:GetDescription()
	
	return self.description

end

