
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Coroutine = Entity.new()
Coroutine.__index = Coroutine

-- =======================================================================

function Coroutine:__class_setup__ (params)

	self.description = params.description

end

-- =======================================================================

function Coroutine:new()

	local new = {}
	setmetatable(new, self)
	
	new.active = true
	new.marks = Collection.new()

	return new

end

-- DEPLOYMENT ============================================================
-- =======================================================================

function Coroutine:Install (node)
	
	node:HostCoroutine(self)
	self:Initialise(node)

end

-- =======================================================================

-- [Coroutine classes can override this]
function Coroutine:Initialise (node)

end

-- ... ===================================================================
-- =======================================================================

function Coroutine:Remove()
	
	self.active = nil
	for mark in self.marks:Each() do

		local host = mark:GetHost()
		host:RemoveMark(mark)

	end

end

-- MARKS =================================================================
-- =======================================================================

function Coroutine:CreateMark (ID, node)
	
	local mark = Mark:NewInstance(ID)
	self.marks:Add(mark)
	
	node:AddMark(mark)

end

-- =======================================================================

function Coroutine:CreateMarkOnConnectedNodes (ID, node, class)
	
	for n in node:GetConnectedNodes(class):Each() do
		self:CreateMark(ID, n)
	end

end

-- =======================================================================

function Coroutine:CreateMarkOnNodesWithinRadius (ID, node, radius, class)
	
	for n in node:GetNodesWithinRadius(radius, class):Each() do
		self:CreateMark(ID, n)
	end

end

-- =======================================================================

function Coroutine:CreateMarkOnAllNodes (ID, network, class)

	for n in network:GetNodes():Each(class) do
		self:CreateMark(ID, n)
	end

end

-- ... ===================================================================
-- =======================================================================

function Coroutine:IsActive()
	
	return self.active == true

end

-- =======================================================================

function Coroutine:GetDescription()
	
	return self.description

end
