
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Data = {}
Data.__index = Data

-- =======================================================================

function Data.new (database, plan)

	local new = {}
	setmetatable(new, Data)

	new.database = database
	new.state = DataState.Undetected

	new:LoadFromPlan(plan)

	return new

end

-- CONSTRUCTION ==========================================================
-- =======================================================================

function Data:LoadFromPlan (plan)

	self.mark = plan:GetMark()
	self.size = plan:GetSize()
	self.labels = plan:GetLabels()
	
end

-- DETECTION =============================================================
-- =======================================================================

function Data:Detect()

	if self.state >= DataState.Detected then
		return
	end

	self.state = DataState.Detected
	self.render:OnDetect()

end

-- =======================================================================

function Data:IsDetected()
	
	return self.state >= DataState.Detected

end

-- DOWNLOAD ==============================================================
-- =======================================================================

function Data:AttemptStartDownload()
	
	if self.database:CanSubroutinesBlockDownload() then
		return
	end

	self:StartDownload()

end

-- =======================================================================

function Data:StartDownload()
	
	self.state = DataState.Download
	self.download = Download.new(self)

	self.render:OnDownloadStart()

end

-- =======================================================================

function Data:ReceiveDownloadPoints (points)

	self.download:ReceiveDownloadPoints(self.database:GetDownloadSpeedMod() * points)
	self.render:OnDownloadAdvance(self.download:GetDownload())

	if self.download:IsComplete() then

		self.state = DataState.Downloaded
		self.render:OnDownloadComplete()
		
		assets:AddData(self)

		networkScreen:ReceiveTutorialImpulse(TutorialImpulse.DataDownload, { data = self })

	end

end

-- =======================================================================

function Data:InterruptDownload()
	
	self.download = nil
	self.state = DataState.Detected

	self.render:OnDownloadInterrupt()

end

-- =======================================================================

function Data:PauseDownload()
	
	self.download:Pause()
	self.render:OnDownloadPause()

end

-- =======================================================================

function Data:ResumeDownload()
	
	self.download:Resume()
	self.render:OnDownloadResume()

end

-- FORBID / REALLOW ======================================================
-- =======================================================================

function Data:ForbidDownload()

	self.render:OnDownloadForbidden()

end

-- =======================================================================

function Data:ReallowDownload()
	
	self.render:OnDownloadReallowed()	
	
end

-- TARGET ================================================================
-- =======================================================================

function Data:BindTarget (target)
	
	self.target = target

end

-- =======================================================================

function Data:IsTarget()
	
	return self.target ~= nil

end

-- RENDER  ===============================================================
-- =======================================================================

function Data:BindRender (render)

	self.render = render

end

-- EXPOSE ================================================================
-- =======================================================================

function Data:GetMark()

	return self.mark

end

-- =======================================================================

function Data:GetSize()

	return self.size

end

-- =======================================================================

function Data:GetState()
	
	return self.state

end

-- =======================================================================

function Data:GetDownload()
	
	return self.download

end

-- =======================================================================

function Data:GetLabels()

	return self.labels

end

