
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Database = {}
Database.__index = Database

-- =======================================================================

setmetatable(Database, Node)

-- =======================================================================

function Database.new (plan)

	local new = Node.new(plan)
	setmetatable(new, Database)

	new.data = Collection.new()

	new:LoadFromPlan(plan)
	
	return new

end

-- CONSTRUCTION ==========================================================
-- =======================================================================

function Database:LoadFromPlan (plan)

	-- Mark space
	self.markSpace = plan:GetMarkSpace()

	-- Data
	for dataPlan in plan:GetDataPlans():Each() do

		local data = Data.new(self, dataPlan)
		self.data:Add(data)

	end

end

-- ACCESS ================================================================
-- =======================================================================

-- [Base Node override]
function Database:ReceiveAccess()

	self:StartScan()

end

-- TRACE =================================================================
-- =======================================================================

-- [Base Node override]
function Database:StartTracePoint (point)
	
	if not deck:CanDownloadUnderTrace() then

		for data in self.data:Each() do
			if data:GetState() == DataState.Download then
				data:InterruptDownload()
			end
		end

		self:ForbidDownload()

	end

end

-- =======================================================================

function Database:ClearTracePoint()
	
	self:ReallowDownload()

end

-- SCAN ==================================================================
-- =======================================================================

function Database:StartScan()

	self.scan = Scan.new(self)

end

-- =======================================================================

function Database:GetScan()

	return self.scan

end

-- DISCONNECT ============================================================
-- =======================================================================

-- [Base Node override]
function Database:Disconnect()

	self.scan = nil

end

-- DOWNLOAD: TRACE =======================================================
-- =======================================================================

function Database:ForbidDownload()

	for data in self.data:Each() do
		data:ForbidDownload()
	end

end

-- =======================================================================

function Database:ReallowDownload()

	for data in self.data:Each() do
		data:ReallowDownload()
	end

end

-- DOWNLOAD: PREVENTION ==================================================
-- =======================================================================

function Database:CanSubroutinesBlockDownload()
	
	for node in self:GetConnectedSubstantialNodes(NodeClass.Router):Each() do

		if node:CanSubroutinesBlock(BlockableAction.Download) then
			return true
		end

	end

end

-- DOWNLOAD: SPEED =======================================================
-- =======================================================================

function Database:GetDownloadSpeedMod()
	
	local mod = 1
	for node in self:GetConnectedSubstantialNodes(NodeClass.Router):Each() do

		local slowsDownloads = function (subroutine) return subroutine:SlowsDownloads() end
		for subroutine in node:GetActiveSubroutines():Select(slowsDownloads):Each() do

			mod = mod * subroutine:GetDownloadSpeedMod()
			subroutine:Reveal()

		end

	end	

	return mod

end

-- TIME ==================================================================
-- =======================================================================

-- [Base Node override]
function Database:ReceiveTimePulse (pulse)
	
	if self.scan then

		self.scan:ReceiveTimePulse(pulse)
		if self.scan:IsComplete() then

			self.scan = nil

		end

	end

end

-- EXPOSE ================================================================
-- =======================================================================

function Database:GetData()

	return self.data

end

-- =======================================================================

function Database:GetMarkSpace()

	return self.markSpace

end

