
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Entity = {}
Entity.__index = Entity

-- =======================================================================

function Entity.new()

	local new = {}
	setmetatable(new, Entity)
	
	new.__classes__ = Map.new()
	
	return new

end

-- =======================================================================

function Entity:NewClass (params)

	local class = {}
	class.__index = class
	
	assert(params.ID, "Entity declared without an ID.")
	assert(not self.__classes__:ContainsKey(params.ID), strFormat("Duplicate ID '%s' within an entity class map.", params.ID))

	setmetatable(class, self)
	self.__classes__[params.ID] = class
	
	class.ID = params.ID

	class.__static__ = {}
	class:__class_setup__(params)
	
	return class

end

-- =======================================================================

function Entity:GetClass (ID)
	
	return assert(self.__classes__[ID], strFormat("Class with an ID '%s' doesn't exist.", ID))

end

-- =======================================================================

function Entity:NewInstance (ID, ...)

	local class = assert(self.__classes__[ID], strFormat("Class with an ID '%s' doesn't exist.", ID))
	return class:new(unpack({...}))

end

-- =======================================================================

function Entity:GetID()
	
	return self.ID

end
