
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

EventQueue = {}
EventQueue.__index = EventQueue

-- =======================================================================

function EventQueue.new()

	local new = {}
	setmetatable(new, EventQueue)
	
	new.queue = Collection.new()

	return new

end

-- =======================================================================

function EventQueue:Push (event, context)
	
	self.queue:Add(EventQueueItem.new(event, context))

end

-- =======================================================================

function EventQueue:GetNextExposedEvent()
	
	while #self.queue > 0 do

		local queueItem = self.queue:PopFirst()

		local event = queueItem:GetEvent()
		local context = queueItem:GetContext()
		event:Execute(context)

		if event:IsExposed() then
			return event
		end

	end

end

-- =======================================================================

function EventQueue:DiscardCharacterEvents (character)

	local isCharactersPersonalEvent = function (eventQueueItem) 

		local event = eventQueueItem:GetEvent() 
		return event:IsPersonal() and event:GetCharacter() == character

	end

	self.queue:RemoveWithPredicate(isCharactersPersonalEvent)

end

