
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

EventStarter = {}
EventStarter.__index = EventStarter

-- =======================================================================

function EventStarter.new()

	local new = {}
	setmetatable(new, EventStarter)
	
	new.events = Map.new()

	return new

end

-- ADD/REMOVE EVENTS =====================================================
-- =======================================================================

function EventStarter:AddEvent (event)
	
	local impulse = event:GetImpulse()
	self:AddEventForImpulse(event, impulse)

end

-- =======================================================================

function EventStarter:AddEventForImpulse (event, impulse)

	self.events[impulse] = self.events[impulse] or Collection.new()
	self.events[impulse]:Add(event)

end

-- =======================================================================

function EventStarter:RemoveEvent (event)

	local impulse = event:GetImpulse()
	self:RemoveEventForImpulse(event, impulse)

end

-- =======================================================================

function EventStarter:RemoveEventForImpulse (event, impulse)
	
	self.events[impulse]:RemoveValue(event)

end

-- ... ===================================================================
-- =======================================================================

function EventStarter:ReceiveImpulse (impulse, context)

	if not self.events:ContainsKey(impulse) then
		return
	end

	local context = Values.new(context)
	for event in self.events[impulse]:Each() do

		if (not event:IsOnCooldown()) and event:MeetsPrerequisites() and event:AcceptsContext(context) then

			local chance = event:GetChance()
			local usesLuckChance = event:UsesLuckChance()
			
			if chance == nil or ((not usesLuckChance) and random:Chance(chance)) or (usesLuckChance and luck:Chance(chance)) then
				
				eventQueue:Push(event, context)

			end

		end

	end

end

-- GAME TIME =============================================================
-- =======================================================================

function EventStarter:ReceiveTick()
	
	for events in self.events:EachValue() do
		for event in events:Each() do

			event:ReceiveTick()

		end
	end

end

