
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

EventTexts = {}
EventTexts.__index = EventTexts

-- =======================================================================

function EventTexts.new()

	local new = {}
	setmetatable(new, EventTexts)
	
	new.eventNarratives = Map.new()
	new.eventTitles = Map.new()
	new.choiceCaptions = Multimap.new(2)
	new.choiceResponses = Multimap.new(2)

	new:LoadFromXML('data/events/botched-operation.xml')
	new:LoadFromXML('data/events/common.xml')
	new:LoadFromXML('data/events/halrow-lamarche.xml')
	new:LoadFromXML('data/events/kita-adachi.xml')
	new:LoadFromXML('data/events/shadowrunner.xml')
	new:LoadFromXML('data/events/street.xml')
	new:LoadFromXML('data/events/vendor.xml')

	return new

end

-- =======================================================================

function EventTexts:LoadFromXML (sourceFilePath)
	
	local xmlRoot = XmlDocument.newFromFile(sourceFilePath):GetRoot()
	for _, eventElement in xmlRoot:EachElement('event') do

		-- ID
		local ID = eventElement:GetRequiredAttribute('ID')

		-- Title
		local title = eventElement:GetRequiredAttribute('title')
		self.eventTitles[ID] = title

		-- Narrative
		local narrativeElement = assert(eventElement:GetElement('narrative'), strFormat("Event with ID '%s' doesn't have a narrative element declared.", ID))
		self.eventNarratives[ID] = Narrative.new(narrativeElement)

		-- Choices
		for _, choiceElement in eventElement:EachElement('choice') do

			self:LoadChoiceFromXML(ID, choiceElement)

		end

	end

end

-- =======================================================================

function EventTexts:LoadChoiceFromXML (event, xmlRoot)
	
	local ID = xmlRoot:GetRequiredAttribute('ID')

	-- Caption
	local caption = xmlRoot:GetRequiredAttribute('caption')
	self.choiceCaptions:Set({ event, ID }, caption)

	-- Response
	local narrativeElement = assert(xmlRoot:GetElement('narrative'), strFormat("Choice with ID '%s' in event '%s' doesn't have a narrative element declared.", ID, event))
	self.choiceResponses:Set({ event, ID }, Narrative.new(narrativeElement))

end

-- ... ===================================================================
-- =======================================================================

function EventTexts:GetEventNarrative (event)
	
	local narrative = self.eventNarratives[event]
	return assert(narrative, strFormat("Event '%s' doesn't have a narrative loaded.", event))

end

-- =======================================================================

function EventTexts:GetEventTitle (event)
	
	local title = self.eventTitles[event]
	return assert(title, strFormat("Event '%s' doesn't have a title loaded.", event))

end

-- =======================================================================

function EventTexts:GetChoiceCaption (event, choice)
	
	local caption = self.choiceCaptions:Get({ event, choice })
	return assert(caption, strFormat("Event '%s' doesn't have a choice caption with ID '%s' loaded.", event, choice))

end

-- =======================================================================

function EventTexts:GetChoiceResponse (event, choice)
	
	local response = self.choiceResponses:Get({ event, choice })
	return assert(response, strFormat("Event '%s' doesn't have a choice response with '%s' loaded.", event, choice))

end

