
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Gateway = {}
Gateway.__index = Gateway

-- =======================================================================

setmetatable(Gateway, Node)

-- =======================================================================

function Gateway.new (plan)

	local new = Node.new(plan)
	setmetatable(new, Gateway)

	new:LoadFromPlan(plan)
	
	return new

end

-- CONSTRUCTION ==========================================================
-- =======================================================================

function Gateway:LoadFromPlan (plan)

	local index = plan:GetCoordinate()
	self.coordinate = Coordinate.new({ rank = random:IntValue(4, 6), index = index })

end

-- ACCESS ================================================================
-- =======================================================================

-- [Base Node override]
function Gateway:ReceiveAccess()

	self:LaunchProbe()

end

-- PROBE =================================================================
-- =======================================================================

function Gateway:LaunchProbe()

	self.probe = Probe.new()

end

-- =======================================================================

function Gateway:RunsProbe()
	
	return self.probe ~= nil

end

-- =======================================================================

function Gateway:GetProbe()

	return self.probe

end

-- DISCONNECT ============================================================
-- =======================================================================

-- [Base Node override]
function Gateway:Disconnect()

	self.probe = nil

end

-- TIME ==================================================================
-- =======================================================================

-- [Base Node override]
function Gateway:ReceiveTimePulse (pulse)
	
	if self.probe then

		self.probe:ReceiveTimePulse(pulse)
		if self.probe:IsComplete() then

			assets:AddCoordinate(self.coordinate)
			self.probe = nil

		end

	end

end

-- HINT ==================================================================
-- =======================================================================

-- [Base Node override]
function Gateway:GetHint_Accessed()

	local coordinate = self.coordinate
	local networkName = coordinate:GetNetworkName()

	local hint = strFormat("< Gateway: %s >", networkName)

	if self:RunsProbe() then

		hint = hint .. "\n-- Connection probe launched --"

	else

		hint = hint .. "\nR-click to connect" .. pick(networkScreen:RunsTutorial(), " [Not available within tutorial networks]", '')

	end

	return hint

end

-- EXPOSE ================================================================
-- =======================================================================

function Gateway:GetCoordinate()
	
	return self.coordinate

end

