
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Narrative = {}
Narrative.__index = Narrative

-- =======================================================================

function Narrative.new (xmlRoot)

	local new = {}
	setmetatable(new, Narrative)
	
	new.clauses = Collection.new()
	new.rewards = Collection.new()
	new:LoadFromXML(xmlRoot)

	return new

end

-- =======================================================================

function Narrative:LoadFromXML (xmlRoot)
	
	for _, clauseElement in xmlRoot:EachElement('clause') do

		local clause = Clause.new(clauseElement)
		self.clauses:Add(clause)

	end

	local rewardFactory = RewardFactory.new()
	for _, rewardElement in xmlRoot:EachElement('reward') do

		local reward = rewardFactory:NewReward(rewardElement)
		self.rewards:Add(reward)

	end

end

-- ... ===================================================================
-- =======================================================================

function Narrative:Evaluate (values)

	local en = EvaluatedNarrative.new()

	for clause in self.clauses:Each() do

		local ec = EvaluatedClause.new(clause, values)
		en:AddClause(ec)

	end

	for reward in self.rewards:Each() do

		local er = reward:Evaluate()
		en:AddReward(er)

	end

	return en

end

-- ... ===================================================================
-- =======================================================================

function Narrative:GetClauses()
	
	return self.clauses

end

-- =======================================================================

function Narrative:GetRewards()
	
	return self.rewards

end

