
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz
	
NetPlanNetwork = {}
NetPlanNetwork.__index = NetPlanNetwork

-- =======================================================================

function NetPlanNetwork.new()

	local new = {}
	setmetatable(new, NetPlanNetwork)
	
	new.nodes = Collection.new()
	new.connections = Collection.new()

	return new

end

-- XML ===================================================================
-- =======================================================================

function NetPlanNetwork.newFromXmlFile (sourceFilePath)
	
	local xmlRoot = XmlDocument.newFromFile(sourceFilePath):GetRoot()
	return NetPlanNetwork.newFromXmlElement(xmlRoot)

end

-- =======================================================================

function NetPlanNetwork.newFromXmlElement (xmlRoot)

	local new = NetPlanNetwork.new()

	-- Name
	new.name = xmlRoot:GetRequiredAttribute('name')

	-- Nodes
	local nodesElement = xmlRoot:GetElement('nodes')
	for _, nodeElement in nodesElement:EachElement('node') do

		local node = new:CreateNetPlanNodeFromXML(nodeElement)
		new.nodes:Add(node)

	end

	-- Connections
	local connectionsElement = xmlRoot:GetElement('connections')
	for _, connectionElement in connectionsElement:EachElement('connection') do

		local connection = NetPlanConnection.newFromXML(connectionElement)
		new.connections:Add(connection)

	end

	-- Trace
	local traceElement = xmlRoot:GetElement('trace')
	new.trace = NetPlanTrace.newFromXML(traceElement)

	return new

end

-- NET PLAN NODE FACTORY =================================================
-- =======================================================================

function NetPlanNetwork:CreateNetPlanNodeFromXML (xmlRoot)

	local class = xmlRoot:GetRequiredAttribute('class')
	class = NodeClass:FromStr(class)

	if class == NodeClass.Database then
		return NetPlanDatabase.newFromXML(xmlRoot)
	end
	
	if class == NodeClass.Gateway then
		return NetPlanGateway.newFromXML(xmlRoot)
	end
	
	if class == NodeClass.Router then
		return NetPlanRouter.newFromXML(xmlRoot)
	end

	return NetPlanNode.newFromXML(xmlRoot)

end

-- NAME ==================================================================
-- =======================================================================

function NetPlanNetwork:SetName (name)

	self.name = name

end

-- EXPOSE ================================================================
-- =======================================================================

function NetPlanNetwork:GetName()
	
	return self.name

end

-- =======================================================================

function NetPlanNetwork:GetNodePlans()
	
	return self.nodes

end

-- =======================================================================

function NetPlanNetwork:GetConnectionPlans()
	
	return self.connections

end

-- =======================================================================

function NetPlanNetwork:GetTracePlan()
	
	return self.trace

end

