
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NetworkBuilder = {}
NetworkBuilder.__index = NetworkBuilder

-- =======================================================================

function NetworkBuilder.new (coordinate)

	local new = {}
	setmetatable(new, NetworkBuilder)

	new.coordinate = coordinate
	new:PreBuild()

	return new

end

-- PRE-BUILD =============================================================
-- =======================================================================

function NetworkBuilder:PreBuild()

	local coordinate = self.coordinate

	local organisation = coordinate:GetOrganisation()
	if organisation then

		self.networkName = strFormat("%s %s %x", organisations:Get(organisation):GetName(), 
			table.random({ "subnet", "sector", "internal", "backbone", "lateral", "prox" }), math.random(16, 128))
		
	else

		self.networkName = "(Unnamed network)"

	end

end

-- NETWORK NAME ==========================================================
-- =======================================================================

function NetworkBuilder:GetNetworkName()
	
	return self.networkName

end

-- BUILD =================================================================
-- =======================================================================

function NetworkBuilder:Build (operation)

	local coordinate = self.coordinate

	local index = coordinate:GetIndex()
	local networkPlan = NetPlanNetwork.newFromXmlFile(strFormat('data/networks/network_%02d.xml', index))

	-- [Temp] While we use XMLs to create the procedural networks as well:
	networkPlan.name = self.networkName

	-- [Temp] Global tweak
	local tracePlan = networkPlan:GetTracePlan()
	tracePlan.durationBase = tracePlan.durationBase * 0.6
	tracePlan.durationIncrement = tracePlan.durationIncrement * 0.6

	local network = Network.new(networkPlan)

	local randomDetails = networkRandomDetails[index]

	local rank = coordinate:GetRank()
	randomDetails.pointsBase = rank
	randomDetails.pointsRandom = math.round(rank / 2)

	networkRandomiser = NetworkRandomiser.new(network, randomDetails)
	networkRandomiser:Run()

	if operation then

		self:BindOperation(network, operation)

	end

	network:Init()
	return network

end

-- OPERATION =============================================================
-- =======================================================================

function NetworkBuilder:BindOperation (network, operation)

	if operation:HasTargets() then

		self:BindOperationTargets(network, operation)

	end

	if operation:HasPayload() then

		operation:GetPayload():BindNetwork(network)

	end

end

-- =======================================================================

function NetworkBuilder:BindOperationTargets (network, operation)

	local dataPool = Collection.new()
	for node in network:GetNodes(NodeClass.Database):Each() do

		for data in node:GetData():Each() do
			dataPool:Add(data)
		end

	end

	local coordinatePool = Collection.new()
	for node in network:GetNodes(NodeClass.Gateway):Each() do

		coordinatePool:Add(node:GetCoordinate())

	end

	for target in operation:GetTargets():Each() do

		local class = target:GetClass()
		if class == OperationTargetClass.Data then

			assert(#dataPool > 0, "Cannot bind a data to the operation target, because there are no more unbound data in the network.")

			local data = dataPool:Random()
			dataPool:RemoveValue(data)
			target:BindData(data)

		end

		if class == OperationTargetClass.Coordinate then

			assert(#coordinatePool > 0, "Cannot bind a coordinate to the operation target, because there are no more unbound coordinates in the network.")

			local coordinate = coordinatePool:Random()
			coordinatePool:RemoveValue(coordinate)
			target:BindCoordinate(coordinate)

		end

	end

end

