
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NewGameStarter = {}
NewGameStarter.__index = NewGameStarter

-- =======================================================================

function NewGameStarter.new (backstories)

	local new = {}
	setmetatable(new, NewGameStarter)

	new.backstories = backstories
	
	return new

end

-- =======================================================================

function NewGameStarter:StartNewGame()

	assets = Assets.new()
	characters = Characters.new()
	credits = Credits.new(2250)
	deck = Deck.new()
	eventQueue = EventQueue.new()
	eventStarter = EventStarter.new()
	state = State.new()
	ticker = Ticker.new()
	worldEvents = WorldEvents.new()

	self:InitAssets()
	self:InitCharacters()
	self:InitDeck()

	self:ExecuteBackstories()

end

-- =======================================================================

function NewGameStarter:InitAssets()

	assets:AddConsole('console-1')
	assets:AddKernel('{3edcdd85-e582-435d-8af5-863b9b304034}')

	assets:AddModule('{10b6dbd9-48d5-46a2-9f98-e55c490c765b}')
	assets:AddModule('{9c54e5c4-26d3-418c-ae3c-8b927ec14b70}')
	assets:AddModule('{96114876-1a81-42bb-af2e-f3271e5bf637}')
	assets:AddModule('{ebe3a219-5a69-4f56-81f9-6341c6f2b846}')
	assets:AddModule('{597f7d8e-948d-45b6-9844-2a433ec3e8eb}')
	assets:AddModule('{dceff74a-747b-4bdf-8eff-1992176a2dac}')

	assets:AddChip('{24ca01f8-3d57-474d-8113-5222a046c20b}')
	assets:AddChip('{3a8bd7e1-b1b8-48d7-b26a-8be7d8a3862d}')
	assets:AddChip('{d17e7820-b9fc-4cbe-a9d8-882532502585}')

	assets:AddCoordinate(Coordinate.new({ rank = random:IntValue(2, 4), index = random:IntValue(1, 2) }))
	assets:AddCoordinate(Coordinate.new({ rank = random:IntValue(4, 5), index = random:IntValue(3, 6) }))

end

-- =======================================================================

function NewGameStarter:InitDeck()
	
	-- Console
	deck:SetConsole('console-1')

	-- Kernel
	deck:SetKernel('{3edcdd85-e582-435d-8af5-863b9b304034}')

	-- Modules
	deck:GetModules():SetItem(1, '{10b6dbd9-48d5-46a2-9f98-e55c490c765b}')
	deck:GetModules():SetItem(2, '{9c54e5c4-26d3-418c-ae3c-8b927ec14b70}')
	deck:GetModules():SetItem(3, '{96114876-1a81-42bb-af2e-f3271e5bf637}')
	deck:GetModules():SetItem(4, '{ebe3a219-5a69-4f56-81f9-6341c6f2b846}')
	deck:GetModules():SetItem(5, '{597f7d8e-948d-45b6-9844-2a433ec3e8eb}')

	-- Chips
	deck:GetChips():SetItem(1, '{d17e7820-b9fc-4cbe-a9d8-882532502585}')
	deck:GetChips():SetItem(2, '{24ca01f8-3d57-474d-8113-5222a046c20b}')

	deck:Rebuild()

end

-- =======================================================================

function NewGameStarter:InitCharacters()

	characters:AddCharacterFromBuilder('street:hustler', { chip_rank = 1, console_rank = 1, module_rank = 1 })

end

-- =======================================================================

function NewGameStarter:ExecuteBackstories()

	for backstory in self.backstories:Each() do
		backstory:Execute()
	end

end

