
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NodeFactory = {}
NodeFactory.__index = NodeFactory

-- =======================================================================

function NodeFactory.new (network)

	local new = {}
	setmetatable(new, NodeFactory)
	
	new.network = network
	
	return new

end

-- =======================================================================

function NodeFactory:NewNode (plan)

	local new
	local class = plan:GetClass()
	
	if class == NodeClass.Database then
		new = Database.new(plan)
	end
	
	if class == NodeClass.Entrance then
		new = Entrance.new(plan)
	end
	
	if class == NodeClass.Gateway then
		new = Gateway.new(plan)
	end

	if class == NodeClass.Pivot then
		new = Pivot.new(plan)
	end

	if class == NodeClass.Router then
		new = Router.new(plan)
	end

	if class == NodeClass.Terminal then
		new = Terminal.new(plan)
	end

	assert(new, strFormat("Cannot create network node with class '%s'.", class:ToStr()))
	
	new.network = self.network
	new.class = class
	
	return new

end

