
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Operation = {}
Operation.__index = Operation

-- =======================================================================

function Operation.new (ID, coordinate)

	local new = {}
	setmetatable(new, Operation)

	new.ID = ID
	new.coordinate = coordinate
	new.values = Values.new()
	new.targets = Collection.new()

	new.impatienceTickdown = Tickdown.new(3)
	new.timeoutTickdown = Tickdown.new(7)
	
	return new

end

-- CONSTRUCTION ==========================================================
-- =======================================================================

function Operation:AddTarget (target)
	
	self.targets:Add(target)

end

-- =======================================================================

function Operation:SetPayload (payload)
	
	self.payload = payload

end

-- IMPATIENCE ============================================================
-- =======================================================================

function Operation:MarkAsImpatient()

	self.impatient = true

end

-- =======================================================================

function Operation:IsImpatient()

	return self.impatient ~= nil

end

-- TIMEOUT ===============================================================
-- =======================================================================

function Operation:Timeout()

	-- TEMP: Disabled
	-- self.character:AbandonOperation(self)

end

-- TIME ==================================================================
-- =======================================================================

function Operation:ReceiveTimePulse (pulse)
	
	if self.payload then
		self.payload:ReceiveTimePulse(pulse)
	end

end

-- GAME TIME =============================================================
-- =======================================================================

function Operation:ReceiveTick()

	-- Impatience
	if self.impatienceTickdown then
	
		self.impatienceTickdown:ReceiveTick()
		if self.impatienceTickdown:IsComplete() then
		
			self.impatienceTickdown = nil
			self:MarkAsImpatient()
		
		end
	
	end
	
	-- Timeout
	if self.timeoutTickdown then
	
		self.timeoutTickdown:ReceiveTick()
		if self.timeoutTickdown:IsComplete() then
		
			self.timeoutTickdown = nil
			self:Timeout()
		
		end
	
	end

end

-- EXPOSE ================================================================
-- =======================================================================

function Operation:GetID()

	return self.ID

end

-- =======================================================================

function Operation:GetCoordinate()
	
	return self.coordinate

end

-- =======================================================================

function Operation:GetValues()

	return self.values

end

-- =======================================================================

function Operation:HasTargets()
	
	return #self.targets > 0

end

-- =======================================================================

function Operation:GetTargets()
	
	return self.targets

end

-- =======================================================================

function Operation:HasPayload()
	
	return self.payload ~= nil

end

-- =======================================================================

function Operation:GetPayload()
	
	return self.payload

end

-- =======================================================================

function Operation:GetDescription()
	
	return assert(self.description, strFormat("Operation with ID '%s' doesn't have its description set.", self.ID))

end

