
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

OperationBuilder = Entity.new()
OperationBuilder.__index = OperationBuilder

-- =======================================================================

function OperationBuilder:__class_setup__ (params)

	self.description = params.description
	self.operationID = params.operationID or params.ID

end

-- =======================================================================

function OperationBuilder:new (details)

	local new = {}
	setmetatable(new, self)

	new.details = Values.new(details)

	return new

end

-- =======================================================================

function OperationBuilder:Build (details)

	local coordinate = self:CreateCoordinate()
	local operation = Operation.new(self.operationID, coordinate)
	
	operation.description = self.description
	
	self.operation = operation
	self:Construct()
	
	return operation

end

-- =======================================================================

-- [Operation builder classes can override this]
function OperationBuilder:CreateCoordinate()

	error(strFormat("Operation with ID '%s' doesn't implement the 'CreateCoordinate()' method.", self.ID))

end

-- =======================================================================

-- [Operation builder classes can override this]
function OperationBuilder:Construct()

	error(strFormat("Operation with ID '%s' doesn't implement the 'Construct()' method.", self.ID))

end

-- UTILITIES =============================================================
-- =======================================================================

function OperationBuilder:AddTargets (class, count)

	local operation = self.operation
	for _ = 1, count do

		operation:AddTarget(OperationTarget.new(class))

	end

end

-- =======================================================================

function OperationBuilder:SetPayload (payload)

	local operation = self.operation
	operation:SetPayload(payload)

end

