
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

PersistenceLoader = {}
PersistenceLoader.__index = PersistenceLoader

-- =======================================================================

function PersistenceLoader.new()

	local new = {}
	setmetatable(new, PersistenceLoader)
	
	return new

end

-- =======================================================================

function PersistenceLoader:Load (sourceFilePath)

	local xmlRoot = XmlDocument.newFromFile(sourceFilePath):GetRoot()
	
	local achievementsElement = xmlRoot:GetElement('achievements')
	self:LoadAchievements(achievementsElement)
	
	local explanationsElement = xmlRoot:GetElement('explanations')
	self:LoadExplanations(explanationsElement)

	local tutorialsElement = xmlRoot:GetElement('tutorials')
	self:LoadTutorials(tutorialsElement)

end

-- =======================================================================

function PersistenceLoader:LoadAchievements (xmlRoot)

	for _, achievementElement in xmlRoot:EachElement('achievement') do

		local achievementID = achievementElement:GetRequiredAttribute('ID')
		local complete = achievementElement:GetAttribute('complete')
		
		if complete then

			local achievement = achievements:GetAchievement(achievementID)
			achievement:MarkAsComplete()

		end

	end

end

-- =======================================================================

function PersistenceLoader:LoadExplanations (xmlRoot)

	for _, explanationElement in xmlRoot:EachElement('explanation') do

		local explanationID = explanationElement:GetRequiredAttribute('ID')
		local suppress = explanationElement:GetAttribute('suppress')
		
		if suppress then

			local explanation = explanations:GetExplanation(explanationID)
			explanation:Suppress()

		end

	end

end

-- =======================================================================

function PersistenceLoader:LoadTutorials (xmlRoot)

	for _, tutorialElement in xmlRoot:EachElement('tutorial') do

		local tutorialID = tutorialElement:GetRequiredAttribute('ID')
		local complete = tutorialElement:GetAttribute('complete')
		
		if complete then

			local tutorial = tutorials:GetTutorial(tutorialID)
			tutorial:MarkAsComplete()

		end

	end

end

