
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

PersistenceSaver = {}
PersistenceSaver.__index = PersistenceSaver

-- =======================================================================

function PersistenceSaver.new()

	local new = {}
	setmetatable(new, PersistenceSaver)
	
	return new

end

-- =======================================================================

function PersistenceSaver:Save (destFilePath)

	local xmlDocument = XmlDocument.newWithRootName('persistence')
	local xmlRoot = xmlDocument:GetRoot()

	local achievementsElement = XmlElement.newWithName('achievements')
	xmlRoot:AddElement(achievementsElement)
	self:SaveAchievements(achievementsElement)

	local explanationsElement = XmlElement.newWithName('explanations')
	xmlRoot:AddElement(explanationsElement)
	self:SaveExplanations(explanationsElement)
	
	local tutorialsElement = XmlElement.newWithName('tutorials')
	xmlRoot:AddElement(tutorialsElement)
	self:SaveTutorials(tutorialsElement)
	
	xmlDocument:SaveToFile(destFilePath)

end

-- =======================================================================

function PersistenceSaver:SaveAchievements (xmlRoot)

	for achievement in achievements:GetAchievements():Each() do

		if achievement:IsComplete() then

			local achievementElement = XmlElement.newWithName('achievement')
			xmlRoot:AddElement(achievementElement)

			achievementElement:SetAttribute('ID', achievement:GetID())
			achievementElement:SetAttribute('complete', true)

		end

	end

end

-- =======================================================================

function PersistenceSaver:SaveExplanations (xmlRoot)

	for explanation in explanations:GetExplanations():EachValue() do

		if explanation:IsSuppressed() then

			local explanationElement = XmlElement.newWithName('explanation')
			xmlRoot:AddElement(explanationElement)

			explanationElement:SetAttribute('ID', explanation:GetID())
			explanationElement:SetAttribute('suppress', true)

		end

	end

end

-- =======================================================================

function PersistenceSaver:SaveTutorials (xmlRoot)

	for tutorial in tutorials:GetTutorials():Each() do

		if tutorial:IsComplete() then

			local tutorialElement = XmlElement.newWithName('tutorial')
			xmlRoot:AddElement(tutorialElement)

			tutorialElement:SetAttribute('ID', tutorial:GetID())
			tutorialElement:SetAttribute('complete', true)

		end

	end

end

