
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Run = {}
Run.__index = Run

-- =======================================================================

function Run.new (network)

	local new = {}
	setmetatable(new, Run)

	new.modules = Slots.new(deck:GetModules():GetCount())
	new.downloads = Downloads.new(network)
	new.tokens = Tokens.new(deck:GetStartTokens(), deck:GetMaxTokens())
	new.network = network
	new.fuses = Collection.new()

	new:CreateKernel()
	new:CreateModules()
	new:CreateFuses()

	return new

end

-- KERNEL ================================================================
-- =======================================================================

function Run:CreateKernel()
	
	self.kernel = Kernel:NewInstance(deck:GetKernel())

end

-- =======================================================================

function Run:GetKernel()
	
	return self.kernel

end

-- MODULES ===============================================================
-- =======================================================================

function Run:CreateModules()
	
	for index, ID in deck:GetModules():EachNotBlank() do

		local module = Module:NewInstance(ID, self.network)
		self.modules:SetItem(index, module)

	end

end

-- =======================================================================

function Run:CreateModuleAtRuntime (index, ID)
	
	local module = Module:NewInstance(ID, self.network)
	self.modules:SetItem(index, module)

end

-- =======================================================================

function Run:GetModules()
	
	return self.modules

end

-- MODULE REACTIONS ======================================================
-- =======================================================================

function Run:ReceiveModuleImpulse (impulse)

	for _, module in self.modules:EachNotBlank() do
	
		module:React(impulse)
	
	end

end

-- FUSES =================================================================
-- =======================================================================

function Run:CreateFuses()
	
	for ID in deck:GetFuses():Each() do

		local fuse = Fuse:NewInstance(ID, self.network)
		self.fuses:Add(fuse)

	end

end

-- =======================================================================

function Run:GetFuses()

	return self.fuses

end

-- TIME ==================================================================
-- =======================================================================

function Run:ReceiveTimePulse (pulse)
	
	if self.terminated then
		return
	end

	self.downloads:ReceiveTimePulse(pulse)

end

-- TERMINATE =============================================================
-- =======================================================================

function Run:Terminate()

	self.network:Disconnect()
	self.terminated = true

end

-- =======================================================================

function Run:IsTerminated()
	
	return self.terminated ~= nil

end

-- DISCONNECT ============================================================
-- =======================================================================

function Run:Disconnect()
	
	self:Terminate()
	networkScreen:Disconnect()

end

-- =======================================================================

function Run:AttemptDisconnect()

	if #self.fuses > 0 then

		local fuse = self.fuses:PopLast()
		fuse:Execute()

		-- This line makes the Fuses stop the Trace when hit:
		self.network:StopTrace()

		return

	end

	self:Disconnect()

end

-- EXPOSE ================================================================
-- =======================================================================

function Run:GetTokens()
	
	return self.tokens

end

