
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Slots = {}
Slots.__index = Slots

-- =======================================================================

function Slots.new (count)

	local new = {}
	setmetatable(new, Slots)
	
	new.items = {}
	new.count = count or 0

	return new

end

-- COUNT =================================================================
-- =======================================================================

function Slots:SetCount (count)
	
	self.count = count

end

-- =======================================================================

function Slots:GetCount()

	return self.count

end

-- =======================================================================

function Slots:GetNonBlankCount()
	
	local count = 0
	for n = 1, self.count do

		if self.items[n] then
			count = count + 1
		end

	end

	return count

end

-- ... ===================================================================
-- =======================================================================

function Slots:SetItem (index, item)

	assert(index <= self.count, strFormat("Cannot set slot with index %d when the slots have been limited to %d items.", index, self.count))
	self.items[index] = item

end

-- =======================================================================

function Slots:HasItem (index)
	
	assert(index <= self.count, strFormat("Cannot access slot with index %d when the slots have been limited to %d items.", index, self.count))
	return self.items[index] ~= nil

end

-- =======================================================================

function Slots:GetItem (index)
	
	assert(index <= self.count, strFormat("Cannot access slot with index %d when the slots have been limited to %d items.", index, self.count))
	return self.items[index]

end

-- =======================================================================

function Slots:ClearItem (index)
	
	assert(index <= self.count, strFormat("Cannot clear slot with index %d when the slots have been limited to %d items.", index, self.count))
	self.items[index] = nil

end

-- =======================================================================

function Slots:GetItemList()

	local result = Collection.new()
	for n = 1, self.count do

		if self.items[n] then
			result:Add(self.items[n])	
		end

	end

	return result

end

-- =======================================================================

function Slots:Each()

	local index = 0
	return function()

		index = index + 1
		if index > self.count then
			return
		end

		return index, self.items[index]

	end

end

-- =======================================================================

function Slots:EachNotBlank()
	
	local index = 0
	return function()

		repeat
			index = index+1
			if index > self.count then
				return
			end

		until self.items[index] ~= nil
		return index, self.items[index]

	end

end
