
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Subroutine = Entity.new()
Subroutine.__index = Subroutine

-- =======================================================================

function Subroutine:__class_setup__ (params)

	self.blocks = Collection.new(params.blocks)
	self.description = params.description
	self.downloadSpeedMod = params.downloadSpeedMod
	self.traits = Collection.new(params.traits)

	self.reactions = Map.new()
	self.blockConditions = Map.new()

end

-- =======================================================================

function Subroutine:new (values, stealth)

	local new = {}
	setmetatable(new, self)

	new.stealth = stealth
	new.values = Values.new(values)
	new.detections = Collection.new()

	return new

end

-- BLOCKS ================================================================
-- =======================================================================

function Subroutine:CheckBlock (action)

	local blockCondition = self.blockConditions[action]
	if self.blocks:Contains(action) or (blockCondition and blockCondition(self)) then

		self:Reveal()
		return true

	end

end

-- REACTIONS =============================================================
-- =======================================================================

function Subroutine:React (impulse, context)

	local reaction = self.reactions[impulse]
	if reaction then

		reaction(self, context)
		self:Reveal()

	end

end

-- STEALTH ===============================================================
-- =======================================================================

function Subroutine:Reveal()

	if self.reveal then
		return
	end

	self.reveal = true

	networkScreen:ReceiveTutorialImpulse(TutorialImpulse.SubroutineReveal, { subroutine = self })

end

-- =======================================================================

function Subroutine:IsRevealed()

	return (not self.stealth) or self.reveal

end

-- ... ===================================================================
-- =======================================================================

function Subroutine:DetectTrait (trait)

	if self.traits:Contains(trait) then

		if not self.detections:Contains(trait) then

			self.detections:Add(trait)

		end

	end

end

-- =======================================================================

function Subroutine:GetDetectedTraits()

	return self.detections

end

-- BREAK =================================================================
-- =======================================================================

function Subroutine:Break (context)

	if not context:HasImpact() then

		if self.host:CanSubroutinesBlock(BlockableAction.Break) then
			return
		end

	end

	self.broken = true
	self:Deactivate()

	self.host:ReceiveMarkImpulse(MarkImpulse.Break)
	self.host:ReceiveExposureImpulse(ExposureImpulse.Break)

	if not context:IsUndetectable() then	

		self.host:ReceiveSubroutineImpulse(SubroutineImpulse.Break)

	end

	networkScreen:ReceiveTutorialImpulse(TutorialImpulse.Break)

end

-- =======================================================================

function Subroutine:PreventsDownloads()
	
	return self.preventsDownloads

end

-- ACTIVE ================================================================
-- =======================================================================

-- [Subroutine classes can override this]
function Subroutine:Deactivate()

end

-- =======================================================================

function Subroutine:IsActive()
	
	if self.broken then
		return
	end

	return true

end

-- DESCRIPTION ===========================================================
-- =======================================================================

-- [Subroutine classes can override this]
function Subroutine:GetDescription()

	return self.description

end

-- ... ===================================================================
-- =======================================================================

function Subroutine:SlowsDownloads()

	return self.downloadSpeedMod ~= nil

end

-- =======================================================================

function Subroutine:GetDownloadSpeedMod()
	
	return self.downloadSpeedMod

end

-- EXPOSE ================================================================
-- =======================================================================

function Subroutine:GetHost()

	return self.host

end

