
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Trace = {}
Trace.__index = Trace

-- =======================================================================

function Trace.new (network, duration)

	local new = {}
	setmetatable(new, Trace)

	new.points = Map.new()
	new.network = network
	new.countdown = Countdown.new(duration)
	
	return new

end

-- ... ===================================================================
-- =======================================================================

function Trace:NewPoint (node)

	local point = TracePoint.new(self, node)
	self.points[node] = point

	node:StartTracePoint(point)

end

-- =======================================================================

function Trace:Spread (node)

	for n in node:GetConnectedNodes():Each() do

		if not self.points:ContainsKey(n) then
			self:NewPoint(n)
		end

	end

end

-- =======================================================================

function Trace:Terminate()
	
	for node, point in self.points:Each() do
		node:ClearTracePoint()
	end

end

-- TIME ==================================================================
-- =======================================================================

function Trace:ReceiveTimePulse (pulse)

	-- Points:
	for point in self.points:EachValue() do
		point:ReceiveTimePulse(pulse)
	end

	-- Countdown:
	self.countdown:ReceiveTimePulse(pulse)

end

-- =======================================================================

function Trace:RestartCountdown (duration)

	self.countdown = Countdown.new(duration)

end

-- EXPOSE ================================================================
-- =======================================================================

function Trace:GetPoint (node)
	
	return self.points[node]

end

-- =======================================================================

function Trace:ContainsNode (node)

	return self.points[node] ~= nil

end

-- =======================================================================

function Trace:GetCountdown()
	
	return self.countdown

end

