
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ConnectionRender = {}
ConnectionRender.__index = ConnectionRender

-- =======================================================================

function ConnectionRender.new (networkRender, connection)

	local new = {}
	setmetatable(new, ConnectionRender)
	
	new.networkRender = networkRender
	new.connection = connection

	return new

end

-- =======================================================================

function ConnectionRender:Draw()

	local nodeA = self.connection:GetNodeA()
	local nodeB = self.connection:GetNodeB()

	if nodeA:GetVisibility() < NodeVisibility.Layout or nodeB:GetVisibility() < NodeVisibility.Layout then
		return
	end

	local screenAX, screenAY = self.networkRender:GetNodeRender(nodeA):GetScreenCoords()
	local screenBX, screenBY = self.networkRender:GetNodeRender(nodeB):GetScreenCoords()

	local start = 0.275

	local pt1X = screenAX*start + screenBX*(1-start)
	local pt1Y = screenAY*start + screenBY*(1-start)
	local pt2X = screenAX*(1-start) + screenBX*start
	local pt2Y = screenAY*(1-start) + screenBY*start

	local color = skin:GetColor('network:connection')
	local alpha = color:GetAlpha()

	if not nodeA:IsAccessed() then
		alpha = alpha - 32
	end

	if not nodeB:IsAccessed() then
		alpha = alpha - 32
	end

	color:SetAsLoveColor(alpha)
	love.graphics.setLineWidth(1)

	local network = networkScreen.network
	if network:RunsTrace() then

		local trace = network:GetTrace()
		if trace:ContainsNode(nodeA) and trace:ContainsNode(nodeB) then

			love.graphics.setLineWidth(3)
			love.graphics.setColor(232, 16, 16, 192)

		end

	end

	love.graphics.line(pt1X, pt1Y, pt2X, pt2Y)

end

