
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

CoroutineRender = {}
CoroutineRender.__index = CoroutineRender

-- =======================================================================

function CoroutineRender.new (coroutine)

	local new = {}
	setmetatable(new, CoroutineRender)
	
	new.coroutine = coroutine
	
	return new

end

-- =======================================================================

function CoroutineRender:Draw (iconX, iconY)

	local size = 7

	skin:GetColor('network:coroutine'):SetAsLoveColor()
	love.graphics.circle('fill', iconX, iconY, size, 4)

	love.graphics.setLineWidth(1)
	skin:GetColor('network:coroutine-outline'):SetAsLoveColor()
	love.graphics.circle('line', iconX, iconY, size, 4)
	
	local curX, curY = mouse:GetCursorPos()
	if math.abs(iconX-curX) < size and math.abs(iconY-curY) < size then

		self:DrawDescription()

	end

	self.screenX = iconX
	self.screenY = iconY
	self.iconSize = size
	
end

-- =======================================================================

function CoroutineRender:DrawDescription()

	local description = self.coroutine:GetDescription()
	
	local routerRender = networkScreen:GetNetworkRender():GetNodeRender(self.coroutine.host)
	routerRender:DrawDescription(description, skin:GetColor('network:coroutine-description-outline'), 420)

end

-- ... ===================================================================
-- =======================================================================

function CoroutineRender:IsOnScreenCoords (curX, curY)

	if not self.coroutine:IsActive() then
		return
	end

	if self.screenX == nil or self.screenY == nil then 
		return
	end

	return math.abs(self.screenX-curX) < self.iconSize and math.abs(self.screenY-curY) < self.iconSize
	
end

-- =======================================================================

function CoroutineRender:GetCoroutine()
	
	return self.coroutine

end

