
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

DataRender = {}
DataRender.__index = DataRender

-- =======================================================================

function DataRender.new (data)

	local new = {}
	setmetatable(new, DataRender)
	
	new.data = data
	new.data:BindRender(new)

	new:CreateButton()
	
	return new

end

-- ... ===================================================================
-- =======================================================================

function DataRender:CreateButton()

	local button = loveFrames.Create('button')
	self.button = button
	
	button:SetText('( Data )')
	button:SetFont('data-network-button')
	button:SetSize(140, 18)
	button:SetVisible(false)
	button:SetCustomBackColor(skin:GetColor('network:data-button'))
	button:SetCustomBackDownColor(skin:GetColor('network:data-button-down'))
	button:SetCustomBackHoverColor(skin:GetColor('network:data-button-hover'))
	
	button.dataRender = self
	button.OnClick = function (object) object.dataRender:OnButtonClick() end

end

-- ... ===================================================================
-- =======================================================================

function DataRender:Release()
	
	self.button:Remove()

end

-- DRAW ==================================================================
-- =======================================================================

function DataRender:Draw()
	
	self.button:draw()

end

-- ... ===================================================================
-- =======================================================================

function DataRender:OnButtonClick()

	local state = self.data:GetState()
	if state == DataState.Detected then

		self.data:AttemptStartDownload()

	end

	if state == DataState.Download then

		if self.data:GetDownload():IsPaused() then

			self.data:ResumeDownload()

		else

			self.data:PauseDownload()

		end

	end

end

-- EVENTS ================================================================
-- =======================================================================

function DataRender:OnDetect()

	self.button:SetVisible(true)

end

-- =======================================================================

function DataRender:OnDownloadStart()

end

-- =======================================================================

function DataRender:OnDownloadAdvance (downloaded)

	local percent = math.round(100 * downloaded / self.data:GetSize())
	self.button:SetText(strFormat('[ DOWNLOAD %d%% ]', percent))

end

-- =======================================================================

function DataRender:OnDownloadComplete()

	self.button:SetVisible(false)

end

-- =======================================================================

function DataRender:OnDownloadInterrupt()

end

-- =======================================================================

function DataRender:OnDownloadPause()
	
	self.button:SetText(self.button:GetText() .. ' <...>')

end

-- =======================================================================

function DataRender:OnDownloadResume()
	
end

-- =======================================================================

function DataRender:OnDownloadForbidden()
	
	self.button:SetText('(Database under trace)')
	self.button:SetEnabled(false)

end

-- =======================================================================

function DataRender:OnDownloadReallowed()

	self.button:SetText('( Data )')
	self.button:SetEnabled(true)

end

-- EXPOSE ================================================================
-- =======================================================================

function DataRender:GetData()
	
	return self.data

end

-- =======================================================================

function DataRender:GetButton()

	return self.button

end

