
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

DatabaseRender = {}
DatabaseRender.__index = DatabaseRender

-- =======================================================================

setmetatable(DatabaseRender, NodeRender)

-- =======================================================================

function DatabaseRender.new (node)

	local new = NodeRender.new(node)
	setmetatable(new, DatabaseRender)

	new.dataRenders = Collection.new()
	new:CreateDataRenders()

	return new

end

-- =======================================================================

function DatabaseRender:CreateDataRenders()

	for data in self.node:GetData():Each() do
	
		local dataRender = DataRender.new(data)
		self.dataRenders:Add(dataRender)
	
	end

end

-- =======================================================================

 -- [Base Node Render override]
function DatabaseRender:Release()
	
	for dataRender in self.dataRenders:Each() do
		dataRender:Release()
	end

end

-- =======================================================================

function DatabaseRender:Draw (screenX, screenY)

	local node = self.node
	local access = node:IsAccessed()
	local radius = 32

	self:SetupRenderColor()

	if access then
		love.graphics.circle('fill', screenX, screenY, radius, 16)
	end

	love.graphics.setLineWidth(1)
	love.graphics.circle('line', screenX, screenY, radius, 16)

	if access then

		skin:GetColor('network:node-details'):SetAsLoveColor()
		love.graphics.circle('line', screenX, screenY, radius - 2, 16)

	end

	self:DrawScan(screenX, screenY)
	self:DrawDataRenders(screenX, screenY)

end

-- =======================================================================

function DatabaseRender:DrawScan (nodeScreenX, nodeScreenY)

	local scan = self.node:GetScan()
	if not scan then
		return
	end

	local mark = scan:GetMark()
	local markSpace = self.node:GetMarkSpace()
	local percent = math.round(100 * mark / markSpace)

	love.graphics.setColor(128, 232, 255, 232)
	fonts:GetFont('scan-label'):SetAsLoveFont()
	love.graphics.printf(strFormat('[SCAN %d%%]', percent), nodeScreenX-100, nodeScreenY+40, 200, 'center')

end

-- =======================================================================

function DatabaseRender:DrawDataRenders (nodeScreenX, nodeScreenY)

	local visibleDataRenders = self.dataRenders:Select(function (dataRender) return dataRender:GetButton():GetVisible() end)
	if #visibleDataRenders == 0 then
		return
	end

	local spaceY = 2
	local buttonSizeY = visibleDataRenders[1]:GetButton():GetHeight()
	local startY = nodeScreenY - (#visibleDataRenders-1)*(buttonSizeY+spaceY)/2

	for n, dataRender in visibleDataRenders:EachIndexed() do

		local buttonX = nodeScreenX + 45
		local buttonY = startY + (n-1)*(buttonSizeY+spaceY) - math.round(buttonSizeY/2)

		dataRender:GetButton():SetPos(buttonX, buttonY)

		if dataRender:GetData():IsTarget() then

			local button = dataRender:GetButton()
			button.customborder = { color = {27, 112, 224, 48}, width = 17 }

		end

		dataRender:Draw()

	end

	local hoverDataRender = visibleDataRenders:First(function (dataRender) return dataRender:GetButton():GetHover() end)
	if hoverDataRender then

		local lastButton = visibleDataRenders:Last():GetButton()

		local descScreenX = lastButton:GetX() + lastButton:GetWidth() / 2
		local descScreenY = lastButton:GetY() + lastButton:GetHeight() + 4

		self:DrawDescription(hoverDataRender, descScreenX, descScreenY)

	end

end

-- =======================================================================

function DatabaseRender:DrawDescription (dataRender, screenX, screenY)
	
	local data = dataRender:GetData()
	local labels = data:GetLabels():Map(function (label) return label:GetLabel() end)
	local text = strFormat('[%s | %.2fTbi]', table.concat(labels, ' / '), data:GetSize() / 1000)

	love.graphics.setColor(192, 192, 232, 232)
	fonts:GetFont('data-description'):SetAsLoveFont()
	love.graphics.printf(text, screenX-120, screenY, 240, 'center')

end

