
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Effect = Entity.new()
Effect.__index = Effect

-- =======================================================================

function Effect:__class_setup__ (params)

	self.__static__.events = params.events or {}

end

-- =======================================================================

function Effect:new (pivot)

	local new = {}
	setmetatable(new, self)

	new.time = 0
	new.pivot = pivot

	new.events = Collection.new()
	for e in Collection.new(self.__static__.events):Each() do

		new.events:Add(EffectEvent.new(e))

	end

	new.onEventRaised = Notice.new{ methodName = 'OnEffectEventRaised' }

	return new

end

-- DRAW ==================================================================
-- =======================================================================

function Effect:Render (screenX, screenY)

	self:Draw(screenX, screenY)

end

-- =======================================================================

-- ===
-- TEMP
-- ===

function Effect:DrawHex (screenX, screenY, color, options)

	options = options or {}

	local time = self.time
	local radius = 1.75 * (options.radius or 64) * (1 - math.min(time / 1, 1))

	for orientation = pick(options.suppressMirror, 1, -1), 1, 2 do

		local coords = {}
		local sides = options.sides or 5
		for n = 1, sides do

			local kappa = 2*math.pi/sides*n + math.pi * time / 2 * (options.rotSpeed or 1) * orientation

			local coordX = screenX + radius * math.sin(kappa)
			local coordY = screenY + radius * math.cos(kappa)

			table.insert(coords, coordX)
			table.insert(coords, coordY)

		end

		color:SetAsLoveColor(math.min(64 * (options.alpha or 1), 255))
		love.graphics.polygon('fill', coords)

		color:SetAsLoveColor(math.min(192 * (options.alpha or 1), 255))
		love.graphics.setLineWidth(1)
		love.graphics.polygon('line', coords)

	end

end

-- =======================================================================

-- ===
-- TEMP
-- ===

function Effect:DrawDiamond (screenX, screenY, color)

	local time = self.time
	local radius = 18 * (1 - math.min(time / 0.65, 1))

	color:SetAsLoveColor(72)
	love.graphics.setLineWidth(1)
	love.graphics.circle('fill', screenX, screenY, radius, 4)
	color:SetAsLoveColor(168)
	love.graphics.circle('line', screenX, screenY, radius, 4)
	
end

-- =======================================================================

-- ===
-- TEMP
-- ===

function Effect:DrawBackHex (color)

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local r = self.time / 0.75
	local radius = r * windowSizeX / 2
	local alpha = 128 * math.max(1-r, 0)

	color = color or Color.newFromHex('000099')

	color:SetAsLoveColor(alpha)
	love.graphics.circle('fill', windowSizeX/2, windowSizeY/2, radius, 6)

	love.graphics.setLineWidth(3)
	color:SetAsLoveColor(math.min(alpha * 1.5, 255))
	love.graphics.circle('line', windowSizeX/2, windowSizeY/2, radius * 1.2, 6)
	love.graphics.circle('line', windowSizeX/2, windowSizeY/2, radius * 0.8, 6)

end

-- EVENTS ================================================================
-- =======================================================================

function Effect:RaiseEvent (event)

	self.onEventRaised:Invoke(self, event)

end

-- TIME ==================================================================
-- =======================================================================

function Effect:ReceiveTimePulse (pulse)

	self.time = self.time + pulse

	for n, event in self.events:ReverseEachIndexed() do
		if event:GetTime() <= self.time then

			self:RaiseEvent(event:GetID())
			self.events:RemoveIndex(n)

		end
	end

	-- TEMP
	if self.time > 1.5 then
		self:Terminate()
	end

end

-- TERMINATION ===========================================================
-- =======================================================================

function Effect:Terminate()
	
	self.terminated = true

end

-- =======================================================================

function Effect:IsTerminated()
	
	return self.terminated ~= nil

end

-- EXPOSE ================================================================
-- =======================================================================

function Effect:GetPivot()
	
	return self.pivot

end

