
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Fonts = {}
Fonts.__index = Fonts

-- =======================================================================

function Fonts.new()

	local new = {}
	setmetatable(new, Fonts)
	
	new.fonts = Map.new()
	new.fontFactory = FontFactory.new()

	return new

end

-- =======================================================================

function Fonts:CreateFont (ID)
	
	local skinFontData = skin:GetFontData(ID)

	local sourceFontFile = skinFontData:GetSourceFontFile()
	local size = skinFontData:GetSize()

	assert(not self.fonts:ContainsKey(ID))
	self.fonts[ID] = self.fontFactory:NewFont(sourceFontFile, size)

end

-- =======================================================================

function Fonts:CreateFonts()

	self.fonts = Map.new()

	self:CreateFont('aspiration-description')
	self:CreateFont('backstory-name')
	self:CreateFont('backstory-description')
	self:CreateFont('backstory-comment')
	self:CreateFont('backstory-unlock-label')
	self:CreateFont('bottom-button')
	self:CreateFont('character-button')
	self:CreateFont('character-role')
	self:CreateFont('character-name')
	self:CreateFont('character-no-actions-label')
	self:CreateFont('character-relationship')
	self:CreateFont('chip-description')
	self:CreateFont('connect-button')
	self:CreateFont('console-name')
	self:CreateFont('coordinate-name')
	self:CreateFont('coordinate-rank')
	self:CreateFont('credits-balance')
	self:CreateFont('credits-section')
	self:CreateFont('credits-text')
	self:CreateFont('data-description')
	self:CreateFont('data-network-button')
	self:CreateFont('data-sell-button')
	self:CreateFont('deck-screen-label')
	self:CreateFont('evasion-description')
	self:CreateFont('event-choice-button')
	self:CreateFont('event-clause')
	self:CreateFont('event-option-cost')
	self:CreateFont('event-reward')
	self:CreateFont('event-title')
	self:CreateFont('explanation-dismiss-label')
	self:CreateFont('explanation-text')
	self:CreateFont('explanation-title')
	self:CreateFont('karma-count')
	self:CreateFont('menu-button')
	self:CreateFont('menu-button-small')
	self:CreateFont('menu-title')
	self:CreateFont('menu-version')
	self:CreateFont('module-description')
	self:CreateFont('module-traits')
	self:CreateFont('module-unlock-button')
	self:CreateFont('module-name')
	self:CreateFont('network-disconnect')
	self:CreateFont('network-disconnect-dismiss')
	self:CreateFont('network-name')
	self:CreateFont('network-hint')
	self:CreateFont('node-tooltip')
	self:CreateFont('operation-abandon-icon')
	self:CreateFont('operation-complete-button')
	self:CreateFont('operation-description')
	self:CreateFont('operation-label')
	self:CreateFont('operation-payload-button')
	self:CreateFont('operation-target')
	self:CreateFont('operation-status')
	self:CreateFont('purchase-button')
	self:CreateFont('scan-label')
	self:CreateFont('screen-button')
	self:CreateFont('screen-label')
	self:CreateFont('screen-switchboard')
	self:CreateFont('screen-text')
	self:CreateFont('token-count')
	self:CreateFont('trace')
	self:CreateFont('tracker-label')
	self:CreateFont('tutorial-button')
	self:CreateFont('tutorial-complete-button')
	self:CreateFont('tutorial-continue')
	self:CreateFont('tutorial-hint')
	self:CreateFont('tutorial-index')
	self:CreateFont('tutorial-name')
	self:CreateFont('tutorial-status')
	self:CreateFont('vulnerable-icon')

end

-- =======================================================================

function Fonts:GetFont (ID)
	
	return assert(self.fonts[ID], strFormat("Font with ID '%s' cannot be retrieved.", ID))

end

