
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

GatewayRender = {}
GatewayRender.__index = GatewayRender

-- =======================================================================

setmetatable(GatewayRender, NodeRender)

-- =======================================================================

function GatewayRender.new (node)

	local new = NodeRender.new(node)
	setmetatable(new, GatewayRender)

	return new

end

-- =======================================================================

function GatewayRender:Draw (screenX, screenY)

	local node = self.node

	self:SetupRenderColor()

	local sizeX = 58
	local sizeY = 48

	if node:IsAccessed() then
		love.graphics.polygon('fill', screenX-sizeX/2, screenY+sizeY/2, screenX, screenY-sizeY/2, screenX+sizeX/2, screenY+sizeY/2)
	end

	love.graphics.setLineWidth(1)
	love.graphics.polygon('line', screenX-sizeX/2, screenY+sizeY/2, screenX, screenY-sizeY/2, screenX+sizeX/2, screenY+sizeY/2)
	
	if node:IsAccessed() then

		sizeX = sizeX / 3
		sizeY = sizeY / 3

		local paddY = math.ceil(sizeY/2)
		local color = skin:GetColor('network:node-details')

		local probe = self.node:RunsProbe()
		if self:IsHovered() and (not probe) then

			color:SetAsLoveColor(32)
			love.graphics.polygon('fill', screenX-sizeX/2, screenY+paddY-sizeY/2, screenX, screenY+paddY+sizeY/2, screenX+sizeX/2, screenY+paddY-sizeY/2)

		end

		color:SetAsLoveColor(pick(probe, 128, 232))
		love.graphics.setLineWidth(pick(probe, 1, 3))
		love.graphics.polygon('line', screenX-sizeX/2, screenY+paddY-sizeY/2, screenX, screenY+paddY+sizeY/2, screenX+sizeX/2, screenY+paddY-sizeY/2)

	end

	self:DrawProbe(screenX, screenY)

end

-- =======================================================================

function GatewayRender:DrawProbe (nodeScreenX, nodeScreenY)
	
	local probe = self.node:GetProbe()
	if not probe then
		return
	end

	love.graphics.setColor(128, 232, 255, 232)
	fonts:GetFont('scan-label'):SetAsLoveFont()

	local periods = ('.'):rep(math.round(love.timer.getTime() / 0.25) % 4)
	love.graphics.printf(strFormat('%s <CONNECTION PROBE LAUNCHED> %s', periods, periods), nodeScreenX-192, nodeScreenY+32, 384, 'center')

end

-- CONTROL ===============================================================
-- =======================================================================

-- [Base Node control override]
function GatewayRender:OnMouseButtonRelease (button, curX, curY)

	if networkScreen:RunsTutorial() then
		return
	end
	
	if button == MouseButton.Right and (not self.node:RunsProbe()) then

		local coordinate = self.node:GetCoordinate()
		local networkBuilder = NetworkBuilder.new(coordinate)
		local network = networkBuilder:Build()

		screen:Set(networkScreen, { network = network })
		coordinate:Expire()

	end

end

