
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ModulesRender = {}
ModulesRender.__index = ModulesRender

-- =======================================================================

function ModulesRender.new (modules)

	local new = {}
	setmetatable(new, ModulesRender)
	
	new.moduleRenders = Collection.new()
	new:CreateModuleRenders(modules)

	return new

end

-- =======================================================================

function ModulesRender:Release()
	
	self:RemoveUI()

end

-- =======================================================================

function ModulesRender:CreateModuleRenders (modules)
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local spaceX = 160
	local startX = (windowSizeX - (modules:GetNonBlankCount()-1)*spaceX) / 2
	local posY = windowSizeY - 100

	local shortcuts = { 'q', 'w', 'e', 'r', 'a', 's', 'd', 'f' }

	for index, module in modules:EachNotBlank() do

		local posX = startX + (index-1)*spaceX
		local moduleRender = ModuleRender.new(module, posX, posY)
		self.moduleRenders:Add(moduleRender)

		moduleRender:SetShortcut(shortcuts[index])

	end

end

-- =======================================================================

function ModulesRender:Draw()
	
	for moduleRender in self.moduleRenders:Each() do
		moduleRender:Draw()
	end

end

-- =======================================================================

function ModulesRender:RemoveUI()

	for moduleRender in self.moduleRenders:Each() do
		moduleRender:RemoveUI()
	end

end

-- =======================================================================

function ModulesRender:GetHoveredModuleRender()
	
	local isHovered = function (mr) return mr:IsHovered() end
	return self.moduleRenders:First(isHovered)

end
