
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NodeRender = {}
NodeRender.__index = NodeRender

-- =======================================================================

function NodeRender.new (node)

	local new = {}
	setmetatable(new, NodeRender)
	
	new.node = node
	new.effects = Effects.new()

	return new

end

-- RELEASE ===============================================================
-- =======================================================================

-- [Node render classes can override this]
function NodeRender:Release()
	
end

-- RENDER ================================================================
-- =======================================================================

function NodeRender:Render()

	local screenX, screenY = self:GetScreenCoords()

	self.effects:RemoveTerminated()
	self.effects:Draw(screenX, screenY)

	self:Draw(screenX, screenY)

end

-- =======================================================================

function NodeRender:SetupRenderColor()
	
	local color = skin:GetColor('network:node')
	local alpha = pick(self.node:IsAccessed(), color:GetAlpha(), 232)

	color:SetAsLoveColor(alpha)

end

-- =======================================================================

function NodeRender:DrawDescription (text, color, size)
	
	local font = fonts:GetFont('node-tooltip')
	local width, lines = font:CalculateSize(text, size)

	local printSizeX = width + 8
	local printSizeY = lines * font:GetHeight() + 4 + 1

	local screenX, screenY = self:GetScreenCoords()
	local baseY = screenY+32

	love.graphics.setColor(16, 16, 16)
	love.graphics.rectangle('fill', screenX-printSizeX/2, baseY-2, printSizeX, printSizeY)

	color:SetAsLoveColor(168)
	love.graphics.setLineWidth(1)
	love.graphics.rectangle('line', screenX-printSizeX/2, baseY-2, printSizeX, printSizeY)

	font:SetAsLoveFont()
	love.graphics.setColor(232, 232, 232, 232)
	love.graphics.printf(text, screenX-size/2, baseY, size, 'center')

end

-- COORDS ================================================================
-- =======================================================================

function NodeRender:GetScreenCoords()
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local screenX = self.node:GetPosX()*2 + windowSizeX/2 - networkScreen.networkControl:GetCameraControl():GetPosX()
	local screenY = self.node:GetPosY()*2 + windowSizeY/2 - networkScreen.networkControl:GetCameraControl():GetPosY()

	return screenX, screenY

end

-- =======================================================================

function NodeRender:IsHovered()
	
	local curX, curY = mouse:GetCursorPos()
	local screenX, screenY = self:GetScreenCoords()

	local radius = 28
	return math.abs(curX-screenX) < radius and math.abs(curY-screenY) < radius

end

-- EFFECTS ===============================================================
-- =======================================================================

function NodeRender:AddEffect (effect)
	
	self.effects:Add(effect)

end

-- TIME ==================================================================
-- =======================================================================

function NodeRender:ReceiveTimePulse (pulse)
	
	self.effects:ReceiveTimePulse(pulse)

end

-- CONTROL ===============================================================
-- =======================================================================

-- [Node render classes can override this]
function NodeRender:OnMouseButtonRelease (button, curX, curY)
	
end

-- EXPOSE ================================================================
-- =======================================================================

function NodeRender:GetNode()

	return self.node

end

