
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NodeRenderFactory = {}
NodeRenderFactory.__index = NodeRenderFactory

-- =======================================================================

function NodeRenderFactory.new()

	local new = {}
	setmetatable(new, NodeRenderFactory)
	
	return new

end

-- =======================================================================

function NodeRenderFactory:NewNodeRender (node)

	local new
	local class = node:GetClass()

	if class == NodeClass.Database then
		new = DatabaseRender.new(node)
	end

	if class == NodeClass.Entrance then
		new = EntranceRender.new(node)
	end

	if class == NodeClass.Gateway then
		new = GatewayRender.new(node)
	end

	if class == NodeClass.Pivot then
		new = PivotRender.new(node)
	end

	if class == NodeClass.Router then
		new = RouterRender.new(node)
	end
	
	if class == NodeClass.Terminal then
		new = TerminalRender.new(node)
	end

	return new

end
