
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

OperationRender = {}
OperationRender.__index = OperationRender

-- =======================================================================

function OperationRender.new (operation)

	local new = {}
	setmetatable(new, OperationRender)
	
	new.operation = operation

	new:CreateUI()

	return new

end

-- UI ====================================================================
-- =======================================================================

function OperationRender:CreateUI()

	if self.operation:HasPayload() then

		self.button = loveFrames.Create('button')	
		self.button:SetSize(260 + 32, 24)
		self.button:SetFont('operation-payload-button')

		self.button.OnClick = function()

			self.operation:GetPayload():StartExecution()

		end

	end

end

-- =======================================================================

function OperationRender:Release()
	
	if self.button then
		self.button:Remove()
	end	
	
end

-- DRAW ==================================================================
-- =======================================================================

function OperationRender:Draw()

	if self.operation:HasTargets() then
		self:DrawTargets()
	end

	if self.operation:HasPayload() then
		self:DrawPayload()
	end

end

-- =======================================================================

function OperationRender:DrawTargets()
		
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseX = 36
	local baseY = windowSizeY-128-24
	local spaceY = 18

	local operation = self.operation

	local backSizeX = 320
	local backSizeY = #operation:GetTargets() * spaceY
	self:DrawBack(baseX, baseY, backSizeX, backSizeY)

	local done = true
	for n, target in operation:GetTargets():EachIndexed() do

		local posY = baseY - (n-1)*spaceY

		local text = ''
		local iconColor = nil

		local class = target:GetClass()
		if class == OperationTargetClass.Data then

			local hash = ''
			local str = toStr(target)
			local hash = strFormat('%s[..]%s', str:sub(-8, -5), str:sub(-2))
			hash = hash:gsub('%d', function (d) return math.pow(d, n) % 10 end )

			text = strFormat('Download Data <XTI: %s>', hash:upper()) 

			local state = target:GetData():GetState()
			if state == DataState.Downloaded then

				iconColor = Color.newFromRGB(102, 236, 87)

			end
			if state == DataState.Download then

				iconColor = Color.newFromRGB(27, 112, 224)

			end
			if state == DataState.Detected then

				iconColor = Color.newFromRGB(232, 232, 0)

			end

			if state ~= DataState.Downloaded then
				done = false
			end

		end

		love.graphics.setColor(232, 232, 232, 232)
		fonts:GetFont('operation-target'):SetAsLoveFont()
		love.graphics.print(text, baseX, posY-6)

		local size = 4

		if iconColor then

			iconColor:SetAsLoveColor()
			love.graphics.rectangle('fill', baseX-12-size, posY-size, 2*size, 2*size)

		else

			love.graphics.setLineWidth(1)
			love.graphics.setColor(232, 232, 232, 128)
			love.graphics.rectangle('line', baseX-12-size, posY-size, 2*size, 2*size)

		end

	end

	local text = pick(done, "[ OPERATION COMPLETE ]", "[ OPERATION ]")

	love.graphics.setColor(128, 128, 232, 232)
	fonts:GetFont('operation-label'):SetAsLoveFont()
	love.graphics.print(text, baseX-12, baseY - (#operation:GetTargets())*spaceY-12)

end

-- =======================================================================

function OperationRender:DrawPayload()
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseX = 36
	local baseY = windowSizeY-128-12
	local backSizeX = self.button:GetWidth() + 16 + 12
	local backSizeY = 48+4

	local operation = self.operation
	local payload = operation:GetPayload()
	local condition = payload:GetCondition()

	if payload:IsComplete() then
		backSizeY = 18
	end

	love.graphics.setColor(128, 128, 232, 232)
	fonts:GetFont('operation-label'):SetAsLoveFont()
	love.graphics.print("[ OPERATION PAYLOAD ]", baseX-12, baseY-backSizeY-12)

	self:DrawBack(baseX, baseY, backSizeX, backSizeY)

	local text = ''
	if payload:IsComplete() then

		self.button:SetVisible(false)
		text = "PAYLOAD SUCCESSFULLY DELIVERED"

	else

		if payload:IsExecuted() then

			local countdown = payload:GetExecutionCountdown()
			local ratio = 1 - countdown:GetCountdown() / payload:GetExecutionTime()

			self.button:SetEnabled(false)
			self.button:SetText(strFormat("[ DELIVERING PAYLOAD %d%% ]", math.round(ratio*100)))

			local buttonX = self.button:GetX()
			local buttonY = self.button:GetY()
			local buttonSizeX = self.button:GetWidth()
			local buttonSizeY = self.button:GetHeight()

			local overX = 4
			local overY = 4

			love.graphics.setColor(128, 128, 232, 192)
			love.graphics.rectangle('fill', buttonX-overX, buttonY-overY, ratio * (buttonSizeX + 2*overX), buttonSizeY + 2*overY)

			--text = strFormat("[ PAYLOAD DELIVERY [%d%%] ]", math.round(ratio*100))
			text = "[ PAYLOAD DELIVERY IN PROGRESS ]"

		else

			if condition:Check() then

				self.button:SetEnabled(true)
				self.button:SetText("EXECUTE PAYLOAD")

				text = "[ READY TO INITIALISE ]"

			else

				self.button:SetEnabled(false)
				self.button:SetText("PAYLOAD WAITING FOR PRE-CONDITIONS")

				text = strFormat("[%s] to initialise", condition:GetText())

			end

		end

		self.button:SetPos(baseX-12, baseY-32-4)
		self.button:draw()

	end

	love.graphics.setColor(232, 232, 232, 232)
	fonts:GetFont('operation-status'):SetAsLoveFont()
	love.graphics.print(text, baseX-12, baseY-4)

end

-- =======================================================================

function OperationRender:DrawBack (baseX, baseY, backSizeX, backSizeY)
	
	local alphaBase = 72
	local alphaStep = 4

	local widthStep = 8

	for n = 1, 4 do

		love.graphics.setColor(64, 64, 128, alphaBase + n*alphaStep)
		love.graphics.rectangle('fill', baseX-24, baseY-backSizeY+6, backSizeX + n*widthStep, backSizeY+6)

	end

end

