
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Skin = {}
Skin.__index = Skin

-- =======================================================================

function Skin.new (ID, dir)

	local new = {}
	setmetatable(new, Skin)

	new.ID = ID
	new.dir = dir

	new.fonts = Map.new()
	new.colors = Map.new()

	return new

end

-- =======================================================================

function Skin:Load()

	local sourceFilePath = self.dir .. '/skin.xml'
	local xmlRoot = XmlDocument.newFromFile(sourceFilePath):GetRoot()

	local fontsElement = assert(xmlRoot:GetElement('fonts'), strFormat("The skin data in '%s' do not contain a '<fonts>' element.", sourceFilePath))
	self:LoadFonts(fontsElement)

	local colorsElement = assert(xmlRoot:GetElement('colors'), strFormat("The skin data in '%s' do not contain a '<colors>' element.", sourceFilePath))
	self:LoadColors(colorsElement)

end

-- FONTS =================================================================
-- =======================================================================

function Skin:LoadFonts (xmlRoot)
	
	for _, element in xmlRoot:EachElement() do

		local ID = element:GetRequiredAttribute('ID')
		local skinFontData = SkinFontData.new(element)

		assert(not self.fonts:ContainsKey(ID), strFormat("Duplicate font ID '%s' declared in skin '%s'.", ID, self.ID))
		self.fonts[ID] = skinFontData

	end

end

-- =======================================================================

function Skin:GetFontData (ID)

	return assert(self.fonts[ID], strFormat("Skin ID '%s' doesn't contain a font with ID '%s'.", self.ID, ID))

end

-- =======================================================================

function Skin:GetFontDir()

	return self.dir .. '/assets/fonts'

end

-- COLORS ================================================================
-- =======================================================================

function Skin:LoadColors (xmlRoot)

	for _, element in xmlRoot:EachElement('color') do

		local ID = element:GetRequiredAttribute('ID')
		local color = Color.newFromHex(toStr(element:GetRequiredAttribute('hex', true)))

		local alpha = element:GetAttribute('alpha')
		if alpha then

			color:SetAlpha(alpha)

		end

		assert(not self.colors:ContainsKey(ID), strFormat("Duplicate color ID '%s' declared in skin '%s'.", ID, self.ID))
		self.colors[ID] = color

	end

end

-- =======================================================================

function Skin:GetColor (ID)
	
	return assert(self.colors[ID], strFormat("Skin ID '%s' doesn't contain a color with ID '%s'.", self.ID, ID))

end

-- ... ===================================================================
-- =======================================================================

function Skin:GetDir()
	
	return self.dir

end

