
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

SubroutineRender = {}
SubroutineRender.__index = SubroutineRender

-- =======================================================================

function SubroutineRender.new (subroutine)

	local new = {}
	setmetatable(new, SubroutineRender)
	
	new.subroutine = subroutine
	new.effects = Effects.new()
	
	return new

end

-- =======================================================================

function SubroutineRender:Draw (screenX, screenY)

	self:DrawEffects(screenX, screenY)
	self:DrawIcon(screenX, screenY)

	self.screenX = screenX
	self.screenY = screenY
	
end

-- =======================================================================

function SubroutineRender:DrawIcon (screenX, screenY)
	
	local size = 7
	self.iconSize = size

	local alphaFill
	local alphaLine

	local subroutine = self.subroutine
	if subroutine:IsRevealed() then

		alphaFill = 255
		alphaLine = 255

	else

		if #subroutine:GetDetectedTraits() > 0 then

			alphaFill = 164
			alphaLine = 128

		else

			alphaFill = 64
			alphaLine = 64

		end

	end

	skin:GetColor('network:subroutine'):SetAsLoveColor(alphaFill)
	love.graphics.circle('fill', screenX, screenY, size, 4)

	love.graphics.setLineWidth(1)
	skin:GetColor('network:subroutine-outline'):SetAsLoveColor(alphaFill)
	love.graphics.circle('line', screenX, screenY, size, 4)
	
	local curX, curY = mouse:GetCursorPos()
	if math.abs(screenX-curX) < size and math.abs(screenY-curY) < size then

		self:DrawDescription()

	end

end

-- =======================================================================

function SubroutineRender:DrawEffects (screenX, screenY)

	self.effects:RemoveTerminated()
	self.effects:Draw(screenX, screenY)

end

-- =======================================================================

function SubroutineRender:DrawDescription()
	
	local text = ''
	local subroutine = self.subroutine

	if subroutine:IsRevealed() then

		text = subroutine:GetDescription()
		--text = strFormat('[ %s ]', subroutine:GetDescription())

	else

		local traits = subroutine:GetDetectedTraits()
		if #traits > 0 then

			for n, trait in traits:EachIndexed() do

				text = text .. strFormat("<Clouded> | Partial detection: %s", trait.description)
				if n < #traits then

					text = text .. '\n'

				end

			end

		else

			text = '<Clouded>'

		end

	end

	local routerRender = networkScreen:GetNetworkRender():GetNodeRender(subroutine.host)
	routerRender:DrawDescription(text, skin:GetColor('network:subroutine-description-outline'), 420)

end

-- EFFECTS ===============================================================
-- =======================================================================

function SubroutineRender:AddEffect (effect)
	
	self.effects:Add(effect)

end

-- TIME ==================================================================
-- =======================================================================

function SubroutineRender:ReceiveTimePulse (pulse)
	
	self.effects:ReceiveTimePulse(pulse)

end

-- ... ===================================================================
-- =======================================================================

function SubroutineRender:IsOnScreenCoords (curX, curY)

	if not self.subroutine:IsActive() then
		return
	end

	if self.screenX == nil or self.screenY == nil then 
		return
	end

	return math.abs(self.screenX-curX) < self.iconSize and math.abs(self.screenY-curY) < self.iconSize
	
end

-- =======================================================================

function SubroutineRender:GetSubroutine()
	
	return self.subroutine

end

