
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

TokensRender = {}
TokensRender.__index = TokensRender

-- =======================================================================

function TokensRender.new()

	local new = {}
	setmetatable(new, TokensRender)
	
	return new

end

-- =======================================================================

function TokensRender:Draw()
	
	local windowSizeY = love.window.getHeight()

	local centerX = 72
	local centerY = windowSizeY - 48

	if networkScreen.network:RunsTrace() then
		centerY = centerY - 28
	end

	local tokens = networkScreen:GetRun():GetTokens():GetCount()

	local max = 6
	local radiuses = { 20, 32 }
	local layers = {}

	while tokens > 0 do

		local radius = radiuses[#layers+1]
		table.insert(layers, { radius = radius, count = math.min(tokens, max), max = max })
		tokens = tokens - max

	end

	if table.empty(layers) then
		table.insert(layers, { radius = radiuses[1], count = 0, max = max })
	end

	skin:GetColor('network:tokens-center'):SetAsLoveColor()
	love.graphics.circle('fill', centerX, centerY, radiuses[1], 6)

	for l, layer in ipairs(layers) do

		local count = layer.count
		local radius = layer.radius
		local max = layer.max

		love.graphics.setLineWidth(1)
		skin:GetColor('network:module-token-circle'):SetAsLoveColor(count/max * 192)
		love.graphics.circle('line', centerX, centerY, radius + (l-1)*1, 6)

		for n = 1, max do

			local kappa = 2*math.pi/max * (n + (l%2 == 1 and 0.5 or 0))
			local dX = math.sin(kappa) * radius
			local dY = math.cos(kappa) * radius

			local posX = centerX + dX
			local posY = centerY + dY

			local alpha = 232
			if n > count then
				alpha = 32
			end

			love.graphics.setLineWidth(1)
			skin:GetColor('network:module-token'):SetAsLoveColor(alpha)
			love.graphics.circle('fill', posX, posY, 9, 6)
			skin:GetColor('network:module-token-outline'):SetAsLoveColor(alpha)
			love.graphics.circle('line', posX, posY, 9, 6)

		end

	end

	tokens = networkScreen:GetRun():GetTokens():GetCount()

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('token-count'):SetAsLoveFont()
	love.graphics.printf(tokens, centerX-20, centerY-6, 2*20, 'center')

	self.render = { centerX = centerX, centerY = centerY }

end

-- =======================================================================

function TokensRender:IsHovered()

	local r = 32
	local curX, curY = mouse:GetCursorPos()
	
	return math.abs(self.render.centerX-curX) < r and math.abs(self.render.centerY-curY) < r

end

