
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

TraceRender = {}
TraceRender.__index = TraceRender

-- =======================================================================

function TraceRender.new()

	local new = {}
	setmetatable(new, TraceRender)
	
	return new

end

-- =======================================================================

function TraceRender:Draw (trace)

	local sizeY = 32
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()
	local baseY = windowSizeY - sizeY

	self:DrawBack(baseY)
	self:DrawBar(trace, baseY)
	self:DrawCountdown(trace, baseY)

end

-- =======================================================================

function TraceRender:DrawBack (baseY)
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	skin:GetColor('network:trace-back'):SetAsLoveColor()
	love.graphics.rectangle('fill', 0, baseY, windowSizeX, windowSizeY-baseY)

end

-- =======================================================================

function TraceRender:DrawBar (trace, baseY)
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local sizeY = windowSizeY - baseY
	local centerY = baseY + sizeY/2
	local barSizeY = sizeY - 4

	local countdown = trace:GetCountdown():GetCountdown()
	local barSizeX = (windowSizeX / 48) * countdown

	skin:GetColor('network:trace-bar'):SetAsLoveColor()
	love.graphics.rectangle('fill', windowSizeX/2-barSizeX/2, centerY-barSizeY/2, barSizeX, barSizeY)

end

-- =======================================================================

function TraceRender:DrawCountdown (trace, baseY)

	local windowSizeX = love.window.getWidth()
	local countdown = trace:GetCountdown():GetCountdown()

	local text = strFormat('Terminates in %.1f', countdown)

	text = strFormat('----- >>> TRACE >>> %s <<< TRACE <<< -----', text)

	fonts:GetFont('trace'):SetAsLoveFont()
	skin:GetColor('network:trace-text'):SetAsLoveColor()
	love.graphics.printf(text:upper(), 0, baseY + 10, windowSizeX, 'center')

end

