
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

TrackerRender = {}
TrackerRender.__index = TrackerRender

-- =======================================================================

function TrackerRender.new (tracker)

	local new = {}
	setmetatable(new, TrackerRender)
	
	new.tracker = tracker

	return new

end

-- ... ===================================================================
-- =======================================================================

function TrackerRender:Release()

	if self.button then
		self.button:Remove()
	end

end

-- ... ===================================================================
-- =======================================================================

function TrackerRender:Draw (baseY, sizeY)

	self:DrawBack(baseY, sizeY)
	self:DrawBackLines(baseY, sizeY)
	self:DrawTexts(baseY, sizeY)
	self:DrawButton(baseY, sizeY)
	self:DrawIndicator(baseY, sizeY)

end

-- =======================================================================

function TrackerRender:DrawBack (baseY, sizeY)
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	love.graphics.setColor(251, 184, 41)
	love.graphics.rectangle('fill', 0, baseY, windowSizeX, sizeY)

	love.graphics.setLineWidth(1)
	love.graphics.setColor(255, 153, 0, 232)
	love.graphics.rectangle('line', 0, baseY, windowSizeX, sizeY)

end

-- =======================================================================

function TrackerRender:DrawBackLines (baseY, sizeY)
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local alpha = 32 + ((os.time() % 1000000) / 1000000) * 64

	love.graphics.setLineWidth(2)
	love.graphics.setColor(255, 128, 64, alpha)

	local slope = 2
	local lineDeltaX = sizeY * slope
	local offsetX = 16
	local spaceX = 48

	for posX = offsetX - 4*lineDeltaX, windowSizeX, spaceX do

		love.graphics.line(posX, baseY, posX+lineDeltaX, baseY+sizeY)

	end

end

-- =======================================================================

function TrackerRender:DrawTexts (baseY, sizeY)
	
	local tracker = self.tracker

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local font = fonts:GetFont('tracker-label')
	local textPosY = baseY + sizeY/2 - font:GetHeight()/2
	
	font:SetAsLoveFont()
	love.graphics.setColor(32, 32, 32, 232)

	local textPosX = windowSizeX * 0.15
	love.graphics.printf((">>> !!! ID-probe !!! <<<"):upper(), textPosX-256, textPosY, 2*256, 'center')

	local evasion = tracker:GetEvasion()
	if not evasion:IsActive() then

		local font = fonts:GetFont('evasion-description')
		local textPosY = baseY + sizeY/2 - font:GetHeight()/2

		font:SetAsLoveFont()
		love.graphics.setColor(32, 32, 32, 232)

		local description = evasion:GetDescription()
		love.graphics.printf(strFormat("%s to evade", description):upper(), 0, textPosY, windowSizeX, 'center')

	end

end

-- =======================================================================

function TrackerRender:DrawButton (baseY, sizeY)

	local tracker = self.tracker
	local evasion = tracker:GetEvasion()

	if not evasion:IsActive() then
		return
	end

	if not self.button then

		local text = strFormat("%s to evade", evasion:GetDescription())

		self.button = loveFrames.Create('button')
		self.button:SetFont('evasion-description')
		self.button:SetText(text)

		local font = fonts:GetFont('evasion-description')
		local width, _ = font:CalculateSize(text, 512)
		self.button:SetSize(width + 128, 42)

		self.button.OnClick = function()

			evasion:ExecuteEvade()

		end

	end

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self.button:SetPos(windowSizeX/2, baseY+sizeY/2, 'center')
	self.button:SetEnabled(evasion:CanExecute())

end

-- =======================================================================

function TrackerRender:DrawIndicator (baseY, sizeY)

	local tracker = self.tracker

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseX = windowSizeX * (1 - 0.15)

	local value = tracker:GetCountdown():GetCountdown()
	local blockSize = 0.65

	local cells = Collection.new()
	if value < blockSize then

		cells:Add({ points = value })

	else

		local pointsOver = value % (2*blockSize)
		local completeCount = 2*math.floor(value / (2*blockSize))

		cells:Add({ points = pointsOver / 2 })

		for n = 1, completeCount do
			cells:Add({ points = blockSize })
		end

		cells:Add({ points = pointsOver / 2 })

	end

	local size = 6
	local spaceX = 1

	local startX = baseX - ((#cells-1)*(size+spaceX))/2
	local baseY = baseY + sizeY/2

	for n, cell in cells:EachIndexed() do

		local posX = startX + (n-1)*(size+spaceX)
		local points = cell.points

		for line = -1, 1 do

			local spaceY = spaceX
			local posY = baseY - size/2 + line*(size+spaceY)

			love.graphics.setColor(231, 53, 37, 232*points/blockSize)
			love.graphics.rectangle('fill', posX-size/2, posY, size, size)

			if points == blockSize then

				love.graphics.setLineWidth(1)
				love.graphics.setColor(128, 128, 0, 64)
				love.graphics.rectangle('line', posX-size/2, posY, size, size)

			end

		end

	end

end

