
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

TutorialRender = {}
TutorialRender.__index = TutorialRender

-- =======================================================================

function TutorialRender.new (tutorial)

	local new = {}
	setmetatable(new, TutorialRender)
	
	new.tutorial = tutorial

	return new

end

-- ... ===================================================================
-- =======================================================================

function TutorialRender:Release()
	
	if self.completeButton then
		self.completeButton:Remove()
	end

end

-- DRAW ==================================================================
-- =======================================================================

function TutorialRender:Draw()
	
	self:DrawHint()
	self:DrawAlternativeHint()

end

-- =======================================================================

function TutorialRender:DrawHint()
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local backSizeX, backSizeY

	local hintTextSizeX = 980
	local posY = windowSizeY - 192 + 16

	if self.tutorial:IsFinished() then

		if self.completeButton == nil then

			self.completeButton = loveFrames.Create('button')
			self.completeButton:SetSize(320, 24)
			self.completeButton:SetPos(windowSizeX/2, posY, true)
			self.completeButton:SetText("Back to tutorial selection")
			self.completeButton:SetFont('tutorial-complete-button')

			self.completeButton.OnClick = function()

				networkScreen:GetRun():Terminate()
				networkScreen:Exit()

			end

		end

		backSizeX = self.completeButton:GetWidth() + 72
		backSizeY = self.completeButton:GetHeight() + 8

	else

		local hint = self.tutorial:GetShownHint()
		local text = hint:GetText()
		
		local font = fonts:GetFont('tutorial-hint')
		local fontHeight = font:GetHeight()

		local width, lines = font:CalculateSize(text, hintTextSizeX)

		backSizeX = width + 64
		backSizeY = lines * fontHeight + 16

	end

	local borderStepX = 4
	local borderStepY = 2

	local steps = 3
	for n = 1, steps do

		local alpha = math.clamp(232 - n*64, 0, 255)
		if n == 1 then

			alpha = 232

		end

		skin:GetColor('network:tutorial-hint-back'):SetAsLoveColor(alpha)
		love.graphics.rectangle('fill', windowSizeX/2 - backSizeX/2 - n*borderStepX, posY - backSizeY/2 - n*borderStepY, backSizeX + 2 * n * borderStepX, backSizeY + 2 * n*borderStepY)

	end

	self.render = { posY = posY, sizeY = backSizeY + steps*borderStepY, sizeX = backSizeX + 2 * steps * borderStepX }

	local caption
	local captionColor

	if self.tutorial:IsFinished() then

		self.completeButton:draw()

		caption = "Tutorial complete"
		captionColor = 232

	else

		local hint = self.tutorial:GetShownHint()
		local text = hint:GetText()

		local font = fonts:GetFont('tutorial-hint')
		local fontHeight = font:GetHeight()

		local width, lines = font:CalculateSize(text, hintTextSizeX)

		font:SetAsLoveFont()
		love.graphics.setColor(232, 232, 232, 232)
		love.graphics.printf(text, windowSizeX/2 - hintTextSizeX/2, posY - lines*fontHeight/2, hintTextSizeX, 'center')

		if hint:HasNextHint() then

			caption = "[Click on this hint to continue]"
			captionColor = pick(self:IsHovered(), 232, 192)

		end

	end

	if caption then

		fonts:GetFont('tutorial-continue'):SetAsLoveFont()
		love.graphics.setColor(captionColor, captionColor, captionColor, 232)
		love.graphics.printf(caption, windowSizeX/2 - 128, posY + backSizeY/2 + steps*borderStepY - 2, 256, 'center')

	end

end

-- =======================================================================

function TutorialRender:DrawAlternativeHint()
	
	if not self.tutorial:ShowsAlternativeHint() then
		return
	end

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local hint = self.tutorial:GetShownAlternativeHint()
	local text = hint:GetText()
	
	local font = fonts:GetFont('tutorial-hint')
	local fontHeight = font:GetHeight()

	local hintTextSizeX = 980
	local width, lines = font:CalculateSize(text, hintTextSizeX)

	local backSizeX = width + 64
	local backSizeY = lines * fontHeight + 16

	local posY = 48

	local borderStepX = 4
	local borderStepY = 2

	local steps = 3
	for n = 1, steps do

		local alpha = math.clamp(232 - n*64, 0, 255)
		if n == 1 then

			alpha = 232

		end

		skin:GetColor('network:tutorial-alternative-hint-back'):SetAsLoveColor(alpha)
		love.graphics.rectangle('fill', windowSizeX/2 - backSizeX/2 - n*borderStepX, posY - backSizeY/2 - n*borderStepY, backSizeX + 2 * n * borderStepX, backSizeY + 2 * n*borderStepY)

	end

	font:SetAsLoveFont()
	love.graphics.setColor(192, 192, 192, 192)
	love.graphics.printf(text, windowSizeX/2 - hintTextSizeX/2, posY - lines*fontHeight/2, hintTextSizeX, 'center')

end

-- ... ===================================================================
-- =======================================================================

function TutorialRender:IsHovered()

	if not self.render then
		return
	end
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local curX, curY = mouse:GetCursorPos()

	return math.abs(curX-windowSizeX/2) < self.render.sizeX/2 and math.abs(curY-(self.render.posY+6)) < self.render.sizeY/2+12

end

