
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

AspirationsScreen = {}
AspirationsScreen.__index = AspirationsScreen

-- =======================================================================

setmetatable(AspirationsScreen, BaseScreen)

-- =======================================================================

AspirationsScreen.__static__ = 
{
	explanationID = 'aspirations'
}

-- =======================================================================

function AspirationsScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, AspirationsScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function AspirationsScreen:Enter (context)

	self:CreateUI()

end

-- =======================================================================

function AspirationsScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function AspirationsScreen:CreateUI()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local posY = windowSizeY - 240 - 72
	local sizeY = 64
	local spaceY = 8

	self.aspirations = Collection.new()
	local aspirations = achievements:GetAspirations()
	for n, aspiration in aspirations:EachIndexed() do 

		local a = { aspiration = aspiration, sizeY = sizeY, posY = posY - (n-1)*(sizeY+spaceY) }
		self.aspirations:Add(a)

	end

	-- Button
	self.menuButton = loveFrames.Create('button')
	self.menuButton:SetSize(420, 32)
	self.menuButton:SetPos(windowSizeX/2, windowSizeY - 128 - 64, true)
	self.menuButton:SetText("Back to Menu")
	self.menuButton:SetFont('menu-button')

	self.menuButton.OnClick = function()

		screen:Set(menuScreen)

	end

end

-- REMOVE UI =============================================================
-- =======================================================================

function AspirationsScreen:RemoveUI()

	self.menuButton:Remove()

end	

-- DRAW ==================================================================
-- =======================================================================

function AspirationsScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)
	self:DrawExplanationButton()

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('ASPIRATIONS', 0, windowSizeY-80, windowSizeX, 'center')

	local sizeX = 720

	for a in self.aspirations:Each() do

		local aspiration = a.aspiration
		local description = aspiration:GetDescription()

		-- Back
		love.graphics.setColor(64, 128, 232, 64)
		love.graphics.rectangle('fill', windowSizeX/2-sizeX/2, a.posY-a.sizeY, sizeX, a.sizeY)

		-- Text
		love.graphics.setColor(232, 232, 232, 232)
		fonts:GetFont('aspiration-description'):SetAsLoveFont()
		love.graphics.printf(description, windowSizeX/2 - 256, a.posY - a.sizeY/2 - 12, 2*256, 'center')

	end

	self.menuButton:draw()

end

-- MOUSE =================================================================
-- =======================================================================

function AspirationsScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckExplanationButtonPress(button, curX, curY)

end
