
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ChipScreen = {}
ChipScreen.__index = ChipScreen

-- =======================================================================

setmetatable(ChipScreen, BaseScreen)

-- =======================================================================

ChipScreen.__static__ = 
{
	
}

-- =======================================================================

function ChipScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, ChipScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function ChipScreen:Enter (context)

	self.character = context.character
	self:CreateUI()

end

-- =======================================================================

function ChipScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function ChipScreen:CreateUI()

	self:CreateBackButton()
	self:CreateSelectionUI()

end

-- =======================================================================

function ChipScreen:CreateSelectionUI()

	local buttonSizeX = 120
	local buttonSizeY = 24

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseY = windowSizeY - 72 - 16
	local spaceY = 72

	local items = Map.new()
	for item in self.character:GetItems(ItemClass.Chip):GetItems():Each() do

		local chip = item:GetItem()
		if not items:ContainsKey(chip) then
			items[chip] = { count = 1, item = item }
		else
			items[chip].count = items[chip].count + 1
		end

	end

	local n = 1
	self.selections = Collection.new()
	for chip, details in items:Each() do

		n = n + 1
		local posY = baseY - (n-1)*spaceY
		local item = details.item

		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('purchase-button')
		button:SetText(strFormat('( BUY ¥%d )', item:GetPrice()))
		button:SetPos(windowSizeX/2, posY-24, true)
		button:SetEnabled(credits:CanSpend(item:GetPrice()))

		self.selections:Add({ item = item, count = details.count, posY = posY, button = button })

		button.OnClick = function()

			credits:Spend(item:GetPrice())
			assets:AddChip(item:GetItem())
			self.character:GetItems(ItemClass.Chip):GetItems():RemoveValue(item)

			eventStarter:ReceiveImpulse(EventImpulse.Purchase, { character = self.character, item = item })
			achievements:ReceiveImpulse(AchievementImpulse.Purchase, { item = item })

			self:RemoveUI()
			self:CreateUI()

		end

		-- ===
		-- TEMP: 
		-- ===

		if n >= 11 then
			break
		end
		
	end

end

-- REMOVE UI =============================================================
-- =======================================================================

function ChipScreen:RemoveUI()

	for selection in self.selections:Each() do
		selection.button:Remove()
	end

	self:RemoveBackButton()

end	

-- DRAW ==================================================================
-- =======================================================================

function ChipScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('PURCHASE CHIPS', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawBackButton()
	self:DrawCredits()

	if #self.selections == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		fonts:GetFont('screen-text'):SetAsLoveFont()
		love.graphics.printf('( No chips available )', 0, windowSizeY-240, windowSizeX, 'center')

	end

	for selection in self.selections:Each() do

		local item = selection.item
		local chip = chipEntities:Get(item:GetItem())

		local posX = windowSizeX/2
		local posY = selection.posY

		love.graphics.setColor(232, 232, 232, 232)
		fonts:GetFont('chip-description'):SetAsLoveFont()
		love.graphics.printf(chip:GetDescription(), 0, posY, windowSizeX, 'center')

		selection.button:draw()

		-- Count
		if selection.count > 1 then

			local spaceX = 8
			local count = selection.count - 1
			local startX = windowSizeX/2 - spaceX*(count-1)/2
			
			for n = 1, count do

				local posY = posY - 42
				local posX = startX + (n-1)*spaceX

				love.graphics.setColor(232, 232, 232, 64)
				love.graphics.circle('fill', posX, posY, 3, 8)

			end

		end

	end

end

-- MOUSE =================================================================
-- =======================================================================

function ChipScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)

end

