
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ConnectionScreen = {}
ConnectionScreen.__index = ConnectionScreen

-- =======================================================================

setmetatable(ConnectionScreen, BaseScreen)

-- =======================================================================

ConnectionScreen.__static__ = 
{
	explanationID = 'coordinates'
}

-- =======================================================================

function ConnectionScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, ConnectionScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function ConnectionScreen:Enter (context)

	self:CreateUI()

end

-- =======================================================================

function ConnectionScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function ConnectionScreen:CreateUI()

	local buttonSizeX = 120
	local buttonSizeY = 18

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local spaceY = 92
	local baseY = windowSizeY - 128 - 48

	self.coordinates = Collection.new()
	for n, coordinate in assets:GetCoordinates():EachIndexed() do

		local posY = baseY - (n-1)*spaceY
		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('connect-button')
		button:SetText('Connect >>>')
		button:SetPos(windowSizeX/2, posY + 12, true)

		local name = coordinate:GetNetworkName()
		local rank = coordinate:GetRankText()

		self.coordinates:Add({ coordinate = coordinate, button = button, name = name, posY = posY, rank = rank })

		button.OnClick = function()

			local networkBuilder = NetworkBuilder.new(coordinate)
			local network = networkBuilder:Build()

			screen:Set(networkScreen, { network = network })
			coordinate:Expire()

		end

	end

end

-- REMOVE UI =============================================================
-- =======================================================================

function ConnectionScreen:RemoveUI()

	for coordinate in self.coordinates:Each() do
		coordinate.button:Remove()
	end

end	

-- DRAW ==================================================================
-- =======================================================================

function ConnectionScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('COORDINATES', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawExplanationButton()

	if #self.coordinates == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		fonts:GetFont('screen-text'):SetAsLoveFont()
		love.graphics.printf('( You have no coordinates to connect to )', 0, windowSizeY-240, windowSizeX, 'center')

	end

	for coordinate in self.coordinates:Each() do

		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('coordinate-name'):SetAsLoveFont()
		love.graphics.printf(strFormat('[ %s ]', coordinate.name), 0, coordinate.posY-36, windowSizeX, 'center')

		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('coordinate-rank'):SetAsLoveFont()
		love.graphics.printf(strFormat("< Expected security: %s >", coordinate.rank), 0, coordinate.posY-36+16, windowSizeX, 'center')

		local lineOuterSpaceX = 240
		local lineInnerSpaceX = coordinate.name:len()*4 + 64
		local linePosY = coordinate.posY-24

		love.graphics.setLineWidth(1)
		love.graphics.setColor(232, 232, 232, 64)
		love.graphics.line(lineOuterSpaceX, linePosY, windowSizeX/2-lineInnerSpaceX, linePosY)
		love.graphics.line(windowSizeX/2+lineInnerSpaceX, linePosY, windowSizeX-lineOuterSpaceX, linePosY)

		coordinate.button:draw()

	end

end

-- MOUSE =================================================================
-- =======================================================================

function ConnectionScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)
	self:CheckExplanationButtonPress(button, curX, curY)

end

