
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ConsoleScreen = {}
ConsoleScreen.__index = ConsoleScreen

-- =======================================================================

setmetatable(ConsoleScreen, BaseScreen)

-- =======================================================================

ConsoleScreen.__static__ = 
{
	
}

-- =======================================================================

function ConsoleScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, ConsoleScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function ConsoleScreen:Enter (context)

	self.character = context.character
	self:CreateUI()

end

-- =======================================================================

function ConsoleScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function ConsoleScreen:CreateUI()

	self:CreateBackButton()
	self:CreateSelectionUI()

end

-- =======================================================================

function ConsoleScreen:CreateSelectionUI()

	local buttonSizeX = 120
	local buttonSizeY = 24

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseY = windowSizeY - 280
	local spaceY = 240

	self.selections = Collection.new()
	for n, item in self.character:GetItems(ItemClass.Console):GetItems():EachIndexed() do

		local posY = baseY - (n-1)*spaceY

		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('purchase-button')
		button:SetPos(windowSizeX/2, posY-24, true)
		button:SetEnabled(credits:CanSpend(item:GetPrice()))

		if assets:GetConsoles():Contains(item:GetItem()) then

			button:SetEnabled(false)
			button:SetText('ALREADY OWNED')

		else

			button:SetEnabled(credits:CanSpend(item:GetPrice()))
			button:SetText(strFormat('( BUY ¥%d )', item:GetPrice()))

		end

		self.selections:Add({ item = item, posY = posY, button = button })

		button.OnClick = function()

			credits:Spend(item:GetPrice())
			assets:AddConsole(item:GetItem())
			self.character:GetItems(ItemClass.Console):GetItems():RemoveValue(item)

			eventStarter:ReceiveImpulse(EventImpulse.Purchase, { character = self.character, item = item })
			achievements:ReceiveImpulse(AchievementImpulse.Purchase, { item = item })

			self:RemoveUI()
			self:CreateUI()

		end

	end

end

-- REMOVE UI =============================================================
-- =======================================================================

function ConsoleScreen:RemoveUI()

	for selection in self.selections:Each() do
		selection.button:Remove()
	end

	self:RemoveBackButton()

end	

-- DRAW ==================================================================
-- =======================================================================

function ConsoleScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('PURCHASE CONSOLE', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawBackButton()
	self:DrawCredits()

	if #self.selections == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		fonts:GetFont('screen-text'):SetAsLoveFont()
		love.graphics.printf('( No consoles available )', 0, windowSizeY-240, windowSizeX, 'center')

	end

	for selection in self.selections:Each() do

		local item = selection.item
		local console = consoleEntities:Get(item:GetItem())

		local posX = windowSizeX/2
		local posY = selection.posY

		local rectSizeX = 240
		love.graphics.setColor(16, 16, 16, 128)
		love.graphics.rectangle('fill', posX-rectSizeX, posY, 2*rectSizeX, 80)

		love.graphics.setLineWidth(1)
		love.graphics.setColor(64, 64, 92, 128)
		love.graphics.rectangle('line', posX-rectSizeX, posY, 2*rectSizeX, 80)

		local text = console:GetName()
		
		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('console-name'):SetAsLoveFont()
		love.graphics.printf(text, posX-rectSizeX, posY+32, 2*rectSizeX, 'center')

		love.graphics.setColor(192, 192, 192, 232)
		local text = strFormat('%d Modules / %d Chips', console:GetModuleSlots(), console:GetChipSlots())
		love.graphics.printf(text, posX-rectSizeX, posY+92, 2*rectSizeX, 'center')

		selection.button:draw()

	end

end

-- MOUSE =================================================================
-- =======================================================================

function ConsoleScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)

end

