
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

CoordinateScreen = {}
CoordinateScreen.__index = CoordinateScreen

-- =======================================================================

setmetatable(CoordinateScreen, BaseScreen)

-- =======================================================================

CoordinateScreen.__static__ = 
{
	
}

-- =======================================================================

function CoordinateScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, CoordinateScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function CoordinateScreen:Enter (context)

	self.character = context.character
	self:CreateUI()

end

-- =======================================================================

function CoordinateScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function CoordinateScreen:CreateUI()

	local buttonSizeX = 120
	local buttonSizeY = 18

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local spaceY = 92
	local baseY = windowSizeY - 128 - 48

	self.coordinates = Collection.new()
	for n, item in self.character:GetItems(ItemClass.Coordinate):GetItems():EachIndexed() do

		local posY = baseY - (n-1)*spaceY
		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('purchase-button')
		button:SetText(strFormat('( BUY ¥%d )', item:GetPrice()))
		button:SetPos(windowSizeX/2, posY + 12, true)
		button:SetEnabled(credits:CanSpend(item:GetPrice()))

		local name = item:GetItem():GetNetworkName()
		local rank = item:GetItem():GetRankText()

		self.coordinates:Add({ item = item, button = button, name = name, posY = posY, rank = rank })

		button.OnClick = function()

			credits:Spend(item:GetPrice())
			assets:AddCoordinate(item:GetItem())
			self.character:GetItems(ItemClass.Coordinate):GetItems():RemoveValue(item)

			eventStarter:ReceiveImpulse(EventImpulse.Purchase, { character = self.character, item = item })
			achievements:ReceiveImpulse(AchievementImpulse.Purchase, { item = item })

			self:RemoveUI()
			self:CreateUI()

		end

	end

	self:CreateBackButton()

end

-- REMOVE UI =============================================================
-- =======================================================================

function CoordinateScreen:RemoveUI()

	for coordinate in self.coordinates:Each() do
		coordinate.button:Remove()
	end

	self:RemoveBackButton()

end	

-- DRAW ==================================================================
-- =======================================================================

function CoordinateScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('PURCHASE COORDINATES', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawBackButton()
	self:DrawCredits()

	if #self.coordinates == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		love.graphics.printf('( There are no coordinates to be purchased )', 0, windowSizeY-240, windowSizeX, 'center')

	end

	for coordinate in self.coordinates:Each() do

		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('coordinate-name'):SetAsLoveFont()
		love.graphics.printf(strFormat('[ %s ]', coordinate.name), 0, coordinate.posY-36, windowSizeX, 'center')

		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('coordinate-rank'):SetAsLoveFont()
		love.graphics.printf(strFormat("< Expected security: %s >", coordinate.rank), 0, coordinate.posY-36+16, windowSizeX, 'center')

		local lineOuterSpaceX = 240
		local lineInnerSpaceX = coordinate.name:len()*4 + 64
		local linePosY = coordinate.posY-24

		love.graphics.setLineWidth(1)
		love.graphics.setColor(232, 232, 232, 64)
		love.graphics.line(lineOuterSpaceX, linePosY, windowSizeX/2-lineInnerSpaceX, linePosY)
		love.graphics.line(windowSizeX/2+lineInnerSpaceX, linePosY, windowSizeX-lineOuterSpaceX, linePosY)

		coordinate.button:draw()

	end

end

-- MOUSE =================================================================
-- =======================================================================

function CoordinateScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)

end

