
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

DataScreen = {}
DataScreen.__index = DataScreen

-- =======================================================================

setmetatable(DataScreen, BaseScreen)

-- =======================================================================

DataScreen.__static__ = 
{
	
}

-- =======================================================================

function DataScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, DataScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function DataScreen:Enter (context)

	self.character = context.character
	self:CreateUI()

end

-- =======================================================================

function DataScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function DataScreen:CreateUI()

	local buttonSizeX = 520
	local buttonSizeY = 24

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local spaceY = 32
	local baseY = windowSizeY - 120

	self.data = Collection.new()
	for n, data in assets:GetData():EachIndexed() do

		local posY = baseY - (n-1)*spaceY

		local price = self.character:AppraiseData(data)

		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('data-sell-button')
		button:SetPos(windowSizeX/2, posY, true)
		button:SetText(strFormat('-- size: %d MBi -- )) DATA (( -- SELL FOR ¥%d --', data:GetSize(), price))

		self.data:Add({ button = button })

		button.OnClick = function()

			assets:GetData():RemoveValue(data)
			credits:Add(price)

			eventStarter:ReceiveImpulse(EventImpulse.DataSell, { character = self.character, price = price })

			self:RemoveUI()
			self:CreateUI()

		end

		if data:IsTarget() then

			button.customborder = { color = {27, 112, 224, 48}, width = 17 }

		end

	end

	self:CreateBackButton()

end

-- REMOVE UI =============================================================
-- =======================================================================

function DataScreen:RemoveUI()

	for data in self.data:Each() do
		data.button:Remove()
	end

	self:RemoveBackButton()

end	

-- DRAW ==================================================================
-- =======================================================================

function DataScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('SELL DATA', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawBackButton()
	self:DrawCredits()

	if #self.data == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		fonts:GetFont('screen-text'):SetAsLoveFont()
		love.graphics.printf('( You have no data to sell )', 0, windowSizeY-240, windowSizeX, 'center')

	end

	for data in self.data:Each() do

		data.button:draw()

	end

end

-- MOUSE =================================================================
-- =======================================================================

function DataScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)

end

