
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

MenuScreen = {}
MenuScreen.__index = MenuScreen

-- =======================================================================

setmetatable(MenuScreen, BaseScreen)

-- =======================================================================

MenuScreen.__static__ = 
{
	
}

-- =======================================================================

function MenuScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, MenuScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function MenuScreen:Enter (context)

	self:CreateUI()

end

-- =======================================================================

function MenuScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function MenuScreen:CreateUI()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local buttonSizeX = 720
	local buttonSizeY = 48

	local buttons = Collection.new()

	self.tutorialButton = loveFrames.Create('button')
	self.tutorialButton:SetSize(buttonSizeX, buttonSizeY)
	self.tutorialButton:SetText("Tutorial")
	self.tutorialButton:SetFont('menu-button')
	buttons:Add(self.tutorialButton)

	self.newGameButton = loveFrames.Create('button')
	self.newGameButton:SetSize(buttonSizeX, buttonSizeY)
	self.newGameButton:SetText("New Game")
	self.newGameButton:SetFont('menu-button')
	buttons:Add(self.newGameButton)

	self.aspirationsButton = loveFrames.Create('button')
	self.aspirationsButton:SetSize(buttonSizeX, buttonSizeY)
	self.aspirationsButton:SetText("Aspirations")
	self.aspirationsButton:SetFont('menu-button')
	buttons:Add(self.aspirationsButton)

	self.creditsButton = loveFrames.Create('button')
	self.creditsButton:SetSize(buttonSizeX, buttonSizeY)
	self.creditsButton:SetText("Credits")
	self.creditsButton:SetFont('menu-button')
	buttons:Add(self.creditsButton)
	
	self.exitButton = loveFrames.Create('button')
	self.exitButton:SetSize(buttonSizeX, buttonSizeY)
	self.exitButton:SetText("Exit")
	self.exitButton:SetFont('menu-button')
	buttons:Add(self.exitButton)

	local spaceY = 12
	local startY = windowSizeY*0.8 - (#buttons - 1) * (buttonSizeY + spaceY)

	for n, button in buttons:EachIndexed() do

		local posY = startY + (n - 1) * (buttonSizeY + spaceY)
		button:SetPos(windowSizeX/2, posY, true)

	end

	-- 'Tutorial' button click
	self.tutorialButton.OnClick = function()

		screen:Set(tutorialsScreen)

	end

	-- 'New Game' button click
	self.newGameButton.OnClick = function()

		screen:Set(backstoriesScreen)

	end
	
	-- 'Aspirations' button click
	self.aspirationsButton.OnClick = function()

		screen:Set(aspirationsScreen)

	end
	
	-- 'Credits' button click
	self.creditsButton.OnClick = function()

		screen:Set(creditsScreen)

	end

	-- 'Exit' button click
	self.exitButton.OnClick = function()

		local ps = PersistenceSaver.new()
		ps:Save(consts.persistenceFilePath)

		love.event.quit()

	end

end

-- REMOVE UI =============================================================
-- =======================================================================

function MenuScreen:RemoveUI()

	self.tutorialButton:Remove()
	self.newGameButton:Remove()
	self.aspirationsButton:Remove()
	self.creditsButton:Remove()
	self.exitButton:Remove()

end	

-- DRAW ==================================================================
-- =======================================================================

function MenuScreen:Draw()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 16, 12, 8, 4)
	self:DrawButtons()
	self:DrawTitle()

end

-- =======================================================================

function MenuScreen:DrawTitle()
	
	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local posY = windowSizeY*0.4

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('menu-title'):SetAsLoveFont()
	love.graphics.printf('Neon Spectre', 0, posY-32, windowSizeX, 'center')

	love.graphics.setColor(232, 232, 232, 232)
	fonts:GetFont('menu-version'):SetAsLoveFont()
	love.graphics.printf('[ pre-alpha v0.1 ]', 0, posY+8, windowSizeX, 'center')

end

-- =======================================================================

function MenuScreen:DrawButtons()

	self.tutorialButton:draw()
	self.newGameButton:draw()
	self.aspirationsButton:draw()
	self.creditsButton:draw()
	self.exitButton:draw()

end

-- MOUSE =================================================================
-- =======================================================================

function MenuScreen:OnMouseButtonPress (button, curX, curY)

end
