
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

ModuleScreen = {}
ModuleScreen.__index = ModuleScreen

-- =======================================================================

setmetatable(ModuleScreen, BaseScreen)

-- =======================================================================

ModuleScreen.__static__ = 
{
	
}

-- =======================================================================

function ModuleScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, ModuleScreen)

	new:Hook()

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function ModuleScreen:Enter (context)

	self.character = context.character
	self:CreateUI()

end

-- =======================================================================

function ModuleScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function ModuleScreen:CreateUI()

	local buttonSizeX = 120
	local buttonSizeY = 24

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local baseX = 256
	local baseY = windowSizeY - 180
	local spaceY = 92

	self.selections = Collection.new()
	for n, item in self.character:GetItems(ItemClass.Module):GetItems():EachIndexed() do

		local posY = baseY - (n-1)*spaceY

		local button = loveFrames.Create('button')
		button:SetSize(buttonSizeX, buttonSizeY)
		button:SetFont('purchase-button')
		button:SetPos(baseX, posY-24, true)

		if assets:GetModules():Contains(item:GetItem()) then

			button:SetEnabled(false)
			button:SetText('ALREADY OWNED')

		else

			button:SetEnabled(credits:CanSpend(item:GetPrice()))
			button:SetText(strFormat('( BUY ¥%d )', item:GetPrice()))

		end

		button.OnClick = function()

			credits:Spend(item:GetPrice())
			assets:AddModule(item:GetItem())
			self.character:GetItems(ItemClass.Module):GetItems():RemoveValue(item)

			eventStarter:ReceiveImpulse(EventImpulse.Purchase, { character = self.character, item = item })
			achievements:ReceiveImpulse(AchievementImpulse.Purchase, { item = item })

			self:RemoveUI()
			self:CreateUI()

		end

		self.selections:Add({ item = item, baseX = baseX, posY = posY, button = button })

		-- ===
		-- TEMP: 
		-- ===

		if n >= 8 then
			break
		end

	end

	self:CreateBackButton()

end

-- REMOVE UI =============================================================
-- =======================================================================

function ModuleScreen:RemoveUI()

	for selection in self.selections:Each() do
		selection.button:Remove()
	end

	self:RemoveBackButton()

end	

-- DRAW ==================================================================
-- =======================================================================

function ModuleScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	love.graphics.setColor(232, 232, 232)
	fonts:GetFont('screen-label'):SetAsLoveFont()
	love.graphics.printf('PURCHASE MODULES', 0, windowSizeY-80, windowSizeX, 'center')

	self:DrawMenuIcon()
	self:DrawScreenButtons()
	self:DrawBackButton()
	self:DrawCredits()

	if #self.selections == 0 then

		love.graphics.setColor(192, 192, 192, 192)
		love.graphics.printf('( You have all the modules that could be purchased here )', 0, windowSizeY-240, windowSizeX, 'center')

	else

		love.graphics.setLineWidth(1)
		love.graphics.setColor(128, 128, 232, 32)
		love.graphics.line(self.selections[1].baseX, 32, self.selections[1].baseX, windowSizeY-128)

	end

	for selection in self.selections:Each() do

		local item = selection.item
		local module = Module:GetClass(item:GetItem())
		local price = item:GetPrice()

		local posX = selection.baseX
		local posY = selection.posY

		local sizeX = 145
		local sizeY = 32

		self:DrawModuleTokens(module, posX, posY, Color.newFromRGB(64, 128, 192))

		love.graphics.setColor(64, 128, 192)
		love.graphics.rectangle('fill', posX-sizeX/2, posY-sizeY/2, sizeX, sizeY)
		love.graphics.setColor(232, 232, 232, 232)
		love.graphics.rectangle('line', posX-sizeX/2, posY-sizeY/2, sizeX, sizeY)

		local name = module:GetName()
		fonts:GetFont('module-name'):SetAsLoveFont()
		love.graphics.printf(name:upper(), posX-sizeX/2, posY-4, sizeX, 'center')

		selection.button:draw()

		local traitLine = ''
		for trait in module:GetTraits():Each() do

			if traitLine:len() > 0 then
				traitLine = traitLine .. ' | '
			end

			traitLine = traitLine .. trait.label

		end

		local description = module:GetDescription()
		local lines = select(2, description:gsub('\n', '\n')) + 1

		love.graphics.setColor(232, 232, 232)
		fonts:GetFont('module-description'):SetAsLoveFont()
		love.graphics.print(description, posX+128, pick(traitLine:len() > 0, posY-18, posY-6) - 12*(lines-1) + 1)

		fonts:GetFont('module-traits'):SetAsLoveFont()
		love.graphics.print(traitLine, posX+128, posY)

	end

end

-- =======================================================================

function ModuleScreen:DrawModuleTokens (module, posX, posY, color)

	if not module:RequiresStaticTokens() then
		return
	end

	posY = posY + 16
	local spaceX = 18

	local tokens = module:GetStaticRequiredTokens()
	local startX = posX - (tokens-1)*spaceX/2

	for n = 1, tokens do

		local posX = startX + (n-1)*spaceX

		color:SetAsLoveColor()
		love.graphics.setLineWidth(1)
		love.graphics.circle('fill', posX, posY, 8, 6)
		love.graphics.circle('line', posX, posY, 8, 6)

	end

end

-- MOUSE =================================================================
-- =======================================================================

function ModuleScreen:OnMouseButtonPress (button, curX, curY)

	self:CheckMenuIconPress(button, curX, curY)
	self:CheckScreenButtonPress(button, curX, curY)

end

