
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

TutorialsScreen = {}
TutorialsScreen.__index = TutorialsScreen

-- =======================================================================

setmetatable(TutorialsScreen, BaseScreen)

-- =======================================================================

TutorialsScreen.__static__ = 
{
	
}

-- =======================================================================

function TutorialsScreen.new()

	local new = BaseScreen.new()
	setmetatable(new, TutorialsScreen)

	return new

end

-- ENTER/LEAVE ===========================================================
-- =======================================================================

function TutorialsScreen:Enter (context)

	self:CreateUI()

end

-- =======================================================================

function TutorialsScreen:Leave()

	self:RemoveUI()

end

-- CREATE UI =============================================================
-- =======================================================================

function TutorialsScreen:CreateUI()

	self:CreateTutorials()
	self:CreateBackButton()

end

-- =======================================================================

function TutorialsScreen:CreateTutorials()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	local spaceY = 16
	local sizeY = 72 + 8
	local posY = windowSizeY - 128 - 128
	
	self.tutorials = Collection.new()
	for n, tutorial in tutorials:GetTutorials():EachIndexed() do

		local button = loveFrames.Create('button')

		button:SetSize(232, 18)
		button:SetPos(windowSizeX/2, posY + 36 + 12, true)
		button:SetText("Start")
		button:SetFont('tutorial-button')
		button.OnClick = function()

			self:StartTutorial(tutorial)

		end

		self.tutorials:Add({ posY = posY, tutorial = tutorial, index = n, sizeY = sizeY, button = button })
		posY = posY - (sizeY + spaceY)

	end

end

-- =======================================================================

function TutorialsScreen:CreateBackButton()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self.backButton = loveFrames.Create('button')
	self.backButton:SetSize(420, 24+4)
	self.backButton:SetPos(windowSizeX/2, windowSizeY-92, true)
	self.backButton:SetText("[ Back to Menu ]")
	self.backButton:SetFont('menu-button-small')
	self.backButton.OnClick = function()

		screen:Set(menuScreen)

	end
	
end

-- REMOVE UI =============================================================
-- =======================================================================

function TutorialsScreen:RemoveUI()

	for tutorial in self.tutorials:Each() do
		tutorial.button:Remove()
	end

	self.backButton:Remove()

end	

-- DRAW ==================================================================
-- =======================================================================

function TutorialsScreen:Draw()

	local windowSizeX = love.window.getWidth()
	local windowSizeY = love.window.getHeight()

	self:DrawBackTexture(1)
	self:DrawBackGradient(4, 24, 18, 8, 4)

	for t in self.tutorials:Each() do

		local tutorial = t.tutorial
		local complete = tutorial:IsComplete()

		local sizeX = 1120
		love.graphics.setColor(128, 128, pick(complete, 255, 192), pick(complete, 64, 48))
		love.graphics.rectangle('fill', windowSizeX/2-sizeX/2, t.posY-t.sizeY + 72, sizeX, t.sizeY)

		love.graphics.setColor(232, 232, 232, 232)
		
		fonts:GetFont('tutorial-index'):SetAsLoveFont()
		love.graphics.printf(strFormat("Tutorial %d:", t.index), windowSizeX/2 - sizeX/2, t.posY + 2, sizeX, 'center')

		fonts:GetFont('tutorial-name'):SetAsLoveFont()
		love.graphics.printf(tutorial:GetName(), windowSizeX/2 - sizeX/2, t.posY + 16, sizeX, 'center')

		if complete then

			fonts:GetFont('tutorial-status'):SetAsLoveFont()
			love.graphics.printf("[Complete]", windowSizeX/2 + sizeX/2 - 256 - 128 + 32, t.posY + t.sizeY/2 - 16 - 2, 256, 'center')

		end

		t.button:draw()

	end

	self.backButton:draw()

end

-- ... ===================================================================
-- =======================================================================

function TutorialsScreen:StartTutorial (tutorial)

	assets = Assets.new()

	if not tutorial:IsLoaded() then
		tutorial:Load()
	end

	self:StartTutorial_Deck(tutorial)
	self:StartTutorial_Network(tutorial)

	tutorial:Start()

end

-- =======================================================================

function TutorialsScreen:StartTutorial_Deck (tutorial)

	deck = Deck.new()
	deck:SetConsole(tutorial:GetConsole())
	deck:SetKernel(tutorial:GetKernel())

	for n, mod in tutorial:GetModules():EachIndexed() do

		deck:GetModules():SetItem(n, mod)

	end

	deck:Rebuild()	

end

-- =======================================================================

function TutorialsScreen:StartTutorial_Network (tutorial)

	local networkPlan = NetPlanNetwork.newFromXmlFile(tutorial:GetNetworkSourceFile())
	networkPlan:SetName("[Tutorial]")

	local network = Network.new(networkPlan)
	network:Init()

	screen:Set(networkScreen, { network = network, tutorial = tutorial })

end
