
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Enum = {}

-- =======================================================================

function Enum.new (values)

	setmetatable(values, Enum)
	
	for _, v in pairs(values) do
		setmetatable(v, EnumValue)
	end
	
	return values
	
end

-- =======================================================================

function Enum.__index (enum, k)

	-- Look in the 'Enum' table.
	-- This allows to dispatch methods.
	return assert(Enum[k], strFormat("Enumeration doesn't contain a value named '%s'.", k))

end


-- =======================================================================

function Enum:FromStr (str)

	local value = table.one(self, function (value) return value.str == str end)
	assert(value, strFormat("Cannot parse '%s' into an enumeration value.", str))
	
	return value

end

-- =======================================================================

EnumValue = {}
EnumValue.__index = EnumValue

-- =======================================================================

function EnumValue.__lt (val1, val2)

	assert(val1.index, "Cannot compare enumeration values that do not have their 'index' value declared.")
	assert(val2.index, "Cannot compare enumeration values that do not have their 'index' value declared.")
	return val1.index < val2.index

end

-- =======================================================================

function EnumValue.__le (val1, val2)

	return val1 < val2 or val1 == val2

end

-- =======================================================================

function EnumValue:ToStr()
	
	return self.str

end

