
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Map = {}

-- =======================================================================

function Map.new (pairs)

	local new = pairs or {}
	setmetatable(new, Map)

	return new

end

-- DISPATCH ==============================================================
-- =======================================================================

function Map.__index (map, index)

	return Map[index]

end

-- METHODS ===============================================================
-- =======================================================================

function Map:Each()
	
	return pairs(self)

end

-- =======================================================================

function Map:EachKey()
	
	local k, v
	return function()
		k, v = next(self, k)
		return k
	end

end

-- =======================================================================

function Map:EachValue()

	local k, v
	return function()
		k, v = next(self, k)
		return v
	end

end

-- =======================================================================

function Map:SelectValues (pred)

	local result = Map.new()
	for k, v in pairs(self) do
		if pred(v) then
			result[k] = v
		end
	end

	return result

end

-- =======================================================================

function Map:SelectKeys (pred)

	local result = Map.new()
	for k, v in pairs(self) do
		if pred(k) then
			result[k] = v
		end
	end

	return result

end

-- =======================================================================

function Map:Lookup (value)
	
	for k, v in pairs(self) do
		if v == value then
			return k
		end
	end

end

-- =======================================================================

function Map:ContainsValue (value)
	
	return self:Lookup(value) ~= nil

end

-- =======================================================================

function Map:ContainsKey (value)
	
	return self[value] ~= nil

end

-- =======================================================================

function Map:ListKeys()
	
	local result = Collection.new()
	for k, _ in pairs(self) do
		result:Add(k)
	end

	return result

end

-- =======================================================================

function Map:ListValues()
	
	local result = Collection.new()
	for _, v in pairs(self) do
		result:Add(v)
	end

	return result

end

-- =======================================================================

function Map:Count()

	local count = 0
	for _, _ in pairs(self) do
		count = count + 1
	end

	return count

end

-- =======================================================================

function Map:RemoveKey (key)

	self[key] = nil

end

