
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

Notice = {}
Notice.__index = Notice

-- =======================================================================

function Notice.new (options)

	local new = {}
	setmetatable(new, Notice)
	
	new.subscribers = Collection.new()
	
	options = options or {}
	new.methodName = options.methodName
	
	return new

end

-- =======================================================================

function Notice:Subscribe (instance, method)

	assert(instance, "No instance was provided to the notice subscription call.")
	if not method then
		method = assert(instance[self.methodName], strFormat("The provided instance doesn't contain the '%s' method.", self.methodName))
	end
	
	self.subscribers:Add({ instance = instance, method = method })

end

-- =======================================================================

function Notice:Unsubscribe (instance, method)

	assert(instance, "No instance was provided to the notice subscription call.")
	if not method then
		method = assert(instance[self.methodName], strFormat("The provided instance doesn't contain the '%s' method.", self.methodName))
	end

	self.subscribers:RemoveWithPredicate(function (s) return s.instance == instance and s.method == method end)

end

-- =======================================================================

function Notice:Invoke (...)

	for subscriber in self.subscribers:Each() do
		subscriber.method(subscriber.instance, unpack({...}))
	end

end

