
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz
NetPlanRouter = {}
NetPlanRouter.__index = NetPlanRouter

-- =======================================================================

setmetatable(NetPlanRouter, NetPlanNode)

-- =======================================================================

function NetPlanRouter.new()

	local new = NetPlanNode.new()
	setmetatable(new, NetPlanRouter)
	
	new.subroutines = Collection.new()

	return new

end

-- XML ===================================================================
-- =======================================================================

function NetPlanRouter.newFromXML (xmlRoot)

	local new = NetPlanRouter.new()
	new:LoadBaseNodeDataFromXML(xmlRoot)

	-- Perimeter
	new.perimeter = xmlRoot:GetAttribute('perimeter')

	-- Subroutines
	for _, subroutineElement in xmlRoot:EachElement('subroutine') do

		local subroutine = NetPlanSubroutine.newFromXML(subroutineElement)
		new.subroutines:Add(subroutine)

	end

	-- Exploit
	local exploitElement = xmlRoot:GetElement('exploit')
	if exploitElement then

		new.exploit = NetPlanExploit.newFromXML(exploitElement)

	end

	return new

end

-- EXPOSE ================================================================
-- =======================================================================

function NetPlanRouter:HasPerimeter()
	
	return self.perimeter ~= nil

end

-- =======================================================================

function NetPlanRouter:GetPerimeter()
	
	return self.perimeter

end

-- =======================================================================

function NetPlanRouter:GetSubroutinePlans()
	
	return self.subroutines

end

-- =======================================================================

function NetPlanRouter:HasExploit()
	
	return self.exploit ~= nil

end

-- =======================================================================

function NetPlanRouter:GetExploitPlan()
	
	return self.exploit

end

