
-- (c) 2015 Martin Ziegler
-- martin.ziegler@outlook.cz

NetworkRandomiser = {}
NetworkRandomiser.__index = NetworkRandomiser

-- =======================================================================

function NetworkRandomiser.new (network, details)

	local new = {}
	setmetatable(new, NetworkRandomiser)
	
	new.network = network
	new.details = details

	new:Init()

	return new

end

-- =======================================================================

function NetworkRandomiser:Init()

	self.subroutines = WeightSet.new()
	self.subroutines:Add({ points = 2, ID = 'block-vision', values = {} }, 100)
	self.subroutines:Add({ points = 1, ID = 'breach-_-alert', values = { alerts = 1 } }, 100)
	self.subroutines:Add({ points = 1, ID = 'breach-_-alert', values = { alerts = 2 } }, 100)
	self.subroutines:Add({ points = 2, ID = 'breach-_-alert-connected', values = {} }, 100)
	self.subroutines:Add({ points = 5, ID = 'breach-_-lose-all-tokens', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'breach-_-lose-tokens', values = { tokens = 2 } }, 100)
	self.subroutines:Add({ points = 4, ID = 'breach-_-lose-tokens', values = { tokens = 4 } }, 100)
	self.subroutines:Add({ points = 4, ID = 'breach-_-trace', values = {} }, 100)
	self.subroutines:Add({ points = 1, ID = 'break-_-alert', values = { alerts = 1 } }, 100)
	self.subroutines:Add({ points = 1, ID = 'break-_-alert', values = { alerts = 2 } }, 100)
	self.subroutines:Add({ points = 2, ID = 'break-_-alert-connected', values = {} }, 100)
	self.subroutines:Add({ points = 6, ID = 'break-_-lose-all-tokens', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'break-_-lose-tokens', values = { tokens = 2 } }, 100)
	self.subroutines:Add({ points = 4, ID = 'break-_-lose-tokens', values = { tokens = 4 } }, 100)
	self.subroutines:Add({ points = 3, ID = 'break-_-trace', values = {} }, 100)
	self.subroutines:Add({ points = 1, ID = 'coroutine-_-alert', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'coroutine-_-alert-connected', values = {} }, 100)
	self.subroutines:Add({ points = 3, ID = 'coroutine-_-trace', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'lock-module', values = { cost = 2 } }, 100)
	self.subroutines:Add({ points = 4, ID = 'lock-module', values = { cost = 4 } }, 100)
	self.subroutines:Add({ points = 2, ID = 'prevent-breach', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'prevent-break', values = {} }, 100)
	self.subroutines:Add({ points = 2, ID = 'spread-trace', values = {} }, 100)

	self.exploits = WeightSet.new()
	self.exploits:Add({ ID = 'clear-all-alerts' }, 35)
	self.exploits:Add({ ID = 'clear-alerts-connected', values = { alerts = 2 } }, 50)
	self.exploits:Add({ ID = 'clear-all-alerts-connected' }, 25)
	self.exploits:Add({ ID = 'detect-all-nodes' }, 25)
	self.exploits:Add({ ID = 'double-tokens' }, 35)
	self.exploits:Add({ ID = 'reveal-all-subroutines' }, 25)
	self.exploits:Add({ ID = 'reveal-subroutines-connected' }, 50)
	self.exploits:Add({ ID = 'terminate-trace' }, 35)
	self.exploits:Add({ ID = 'tokens', values = { tokens = 2 } }, 75)
	self.exploits:Add({ ID = 'tokens', values = { tokens = 4 } }, 25)

	self.exposures = WeightSet.new()
	self.exposures:Add('breach', 50)
	self.exposures:Add('breach-connected', 75)
	self.exposures:Add('break', 45)
	self.exposures:Add('break-all', 75)

	self.nodeExploits = Map.new()
	self.nodeSubroutines = Map.new()	
	for node in self.network:GetNodes(NodeClass.Router):Each() do

		self.nodeSubroutines[node] = Collection.new()

	end

end

-- =======================================================================

function NetworkRandomiser:Run()

	self:BuildMirrors()	

	self:PrepareRandomSubroutines()
	self:PrepareFixedSubroutines()
	self:CreateSubroutines()

	self:PrepareRandomExploits()
	self:CreateExploits()

end

-- =======================================================================

function NetworkRandomiser:BuildMirrors()

	local mirrors = {}
	self.mirrors = mirrors	

	local details = self.details
	local network = self.network

	local routers = {}
	for node in network:GetNodes():Each() do

		if node:GetClass() == NodeClass.Router then
			table.insert(routers, node)
		end

	end

	for nodeIDs, mirrorDetails in pairs(details.mirrors) do

		local nodes = {}
		for _, nodeID in ipairs(nodeIDs) do
			table.insert(nodes, network:GetNodeWithID(nodeID))
		end

		table.insert(mirrors, { nodes = nodes, details = mirrorDetails })

	end

	for _, node in ipairs(routers) do

		local contained
		for _, mirror in ipairs(mirrors) do

			if table.contains(mirror.nodes, node) then
				contained = true
				break
			end

		end

		if not contained then
			table.insert(mirrors, { nodes = { node }, details = {} })
		end

	end	

end

-- SUBROUTINES ===========================================================
-- =======================================================================

function NetworkRandomiser:PrepareRandomSubroutines()
	
	for _, mirror in ipairs(self.mirrors) do
		self:PrepareRandomSubroutinesForMirror(mirror)
	end

end

-- =======================================================================

function NetworkRandomiser:PrepareRandomSubroutinesForMirror (mirror)

	local details = mirror.details

	local points = details.points or self.details.pointsBase
	points = math.max(points + random:IntValue(-1, self.details.pointsRandom), 0)

	local maxSubroutineCount = 3
	local subroutines = Collection.new()

	repeat

		subroutines:Clear()
		local spend = points

		while spend > 0 do

			local subroutine = self.subroutines:Random()
			if spend >= subroutine.points then

				local stealth
				if random:Chance(0.5) then
					stealth = true
				end

				spend = spend - subroutine.points
				subroutines:Add({ ID = subroutine.ID, values = subroutine.values, stealth = stealth })

			end

		end

	until #subroutines <= maxSubroutineCount
	
	for subroutine in subroutines:Each() do
		for _, node in ipairs(mirror.nodes) do

			self.nodeSubroutines[node]:Add(subroutine)

		end
	end

end

-- =======================================================================

function NetworkRandomiser:PrepareFixedSubroutines()
	
	local items = self.details.subroutines or {}
	for _, item in ipairs(items) do

		local node = self.network:GetNodeWithID(item.node)
		self.nodeSubroutines[node]:Add({ ID = item.ID, values = item.values, stealth = item.stealth })

	end

end

-- =======================================================================

function NetworkRandomiser:CreateSubroutines()
	
	for node, subs in self.nodeSubroutines:Each() do

		local comp = function (s1, s2) 

			if (not s1.stealth) and s2.stealth then
				return true
			end

		end

		subs:Sort(comp)
		for subroutine in subs:Each() do

			local subroutine = Subroutine:NewInstance(subroutine.ID, subroutine.values, subroutine.stealth)
			node:HostSubroutine(subroutine)

		end

	end

end

-- EXPLOITS ==============================================================
-- =======================================================================

function NetworkRandomiser:PrepareRandomExploits()
	
	for _, mirror in ipairs(self.mirrors) do
		self:PrepareRandomExploitForMirror(mirror)
	end

end

-- =======================================================================

function NetworkRandomiser:PrepareRandomExploitForMirror (mirror)

	local count = self.nodeExploits:Count()
	local chance = 0.45 - 0.2 * count

	if random:Chance(chance) then

		local exploit = self.exploits:Random()
		local exposure = self.exposures:Random()

		for _, node in ipairs(mirror.nodes) do
			
			self.nodeExploits[node] = { ID = exploit.ID, exposure = exposure, values = exploit.values }

		end

	end

end

-- =======================================================================

function NetworkRandomiser:CreateExploits()

	for node, e in pairs(self.nodeExploits) do

		local exposure = ExposureCondition:NewInstance(e.exposure)
		local exploit = Exploit:NewInstance(e.ID, exposure, e.values)
			
		node:SetExploit(exploit)
	
	end

end

